# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum
import typing
import uuid

import bleak_winrt._winrt as _winrt
try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.storage
except Exception:
    pass

try:
    import bleak_winrt.windows.system
except Exception:
    pass

class ByteOrder(enum.IntEnum):
    LITTLE_ENDIAN = 0
    BIG_ENDIAN = 1

class FileOpenDisposition(enum.IntEnum):
    OPEN_EXISTING = 0
    OPEN_ALWAYS = 1
    CREATE_NEW = 2
    CREATE_ALWAYS = 3
    TRUNCATE_EXISTING = 4

class InputStreamOptions(enum.IntFlag):
    NONE = 0
    PARTIAL = 0x1
    READ_AHEAD = 0x2

class UnicodeEncoding(enum.IntEnum):
    UTF8 = 0
    UTF16_L_E = 1
    UTF16_B_E = 2

class Buffer(IBuffer, _winrt.winrt_base):
    ...
    length: int
    capacity: int
    def create_copy_from_memory_buffer(input: bleak_winrt.windows.foundation.IMemoryBuffer) -> Buffer:
        ...
    def create_memory_buffer_over_i_buffer(input: IBuffer) -> bleak_winrt.windows.foundation.MemoryBuffer:
        ...

class DataReader(IDataReader, bleak_winrt.windows.foundation.IClosable, typing.ContextManager[DataReader], _winrt.winrt_base):
    ...
    unicode_encoding: UnicodeEncoding
    input_stream_options: InputStreamOptions
    byte_order: ByteOrder
    unconsumed_buffer_length: int
    def read_byte() -> int:
        ...
    def read_bytes(value_size: int) -> typing.List[int]:
        ...
    def read_buffer(length: int) -> IBuffer:
        ...
    def read_boolean() -> bool:
        ...
    def read_guid() -> uuid.UUID:
        ...
    def read_int16() -> int:
        ...
    def read_int32() -> int:
        ...
    def read_int64() -> int:
        ...
    def read_uint16() -> int:
        ...
    def read_uint32() -> int:
        ...
    def read_uint64() -> int:
        ...
    def read_single() -> float:
        ...
    def read_double() -> float:
        ...
    def read_string(code_unit_count: int) -> str:
        ...
    def read_date_time() -> bleak_winrt.windows.foundation.DateTime:
        ...
    def read_time_span() -> bleak_winrt.windows.foundation.TimeSpan:
        ...
    def load_async(count: int) -> DataReaderLoadOperation:
        ...
    def detach_buffer() -> IBuffer:
        ...
    def detach_stream() -> IInputStream:
        ...
    def close() -> None:
        ...
    def from_buffer(buffer: IBuffer) -> DataReader:
        ...

class DataReaderLoadOperation(bleak_winrt.windows.foundation.IAsyncOperation[int], bleak_winrt.windows.foundation.IAsyncInfo, _winrt.winrt_base):
    ...
    error_code: bleak_winrt.windows.foundation.HResult
    id: int
    status: bleak_winrt.windows.foundation.AsyncStatus
    completed: bleak_winrt.windows.foundation.AsyncOperationCompletedHandler[int]
    def get_results() -> int:
        ...
    def cancel() -> None:
        ...
    def close() -> None:
        ...

class DataWriter(IDataWriter, bleak_winrt.windows.foundation.IClosable, typing.ContextManager[DataWriter], _winrt.winrt_base):
    ...
    unicode_encoding: UnicodeEncoding
    byte_order: ByteOrder
    unstored_buffer_length: int
    def write_byte(value: int) -> None:
        ...
    def write_bytes(value: typing.Sequence[int]) -> None:
        ...
    def write_buffer(buffer: IBuffer) -> None:
        ...
    def write_buffer(buffer: IBuffer, start: int, count: int) -> None:
        ...
    def write_boolean(value: bool) -> None:
        ...
    def write_guid(value: uuid.UUID) -> None:
        ...
    def write_int16(value: int) -> None:
        ...
    def write_int32(value: int) -> None:
        ...
    def write_int64(value: int) -> None:
        ...
    def write_uint16(value: int) -> None:
        ...
    def write_uint32(value: int) -> None:
        ...
    def write_uint64(value: int) -> None:
        ...
    def write_single(value: float) -> None:
        ...
    def write_double(value: float) -> None:
        ...
    def write_date_time(value: bleak_winrt.windows.foundation.DateTime) -> None:
        ...
    def write_time_span(value: bleak_winrt.windows.foundation.TimeSpan) -> None:
        ...
    def write_string(value: str) -> int:
        ...
    def measure_string(value: str) -> int:
        ...
    def store_async() -> DataWriterStoreOperation:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...
    def detach_buffer() -> IBuffer:
        ...
    def detach_stream() -> IOutputStream:
        ...
    def close() -> None:
        ...

class DataWriterStoreOperation(bleak_winrt.windows.foundation.IAsyncOperation[int], bleak_winrt.windows.foundation.IAsyncInfo, _winrt.winrt_base):
    ...
    error_code: bleak_winrt.windows.foundation.HResult
    id: int
    status: bleak_winrt.windows.foundation.AsyncStatus
    completed: bleak_winrt.windows.foundation.AsyncOperationCompletedHandler[int]
    def get_results() -> int:
        ...
    def cancel() -> None:
        ...
    def close() -> None:
        ...

class FileInputStream(IInputStream, bleak_winrt.windows.foundation.IClosable, typing.ContextManager[FileInputStream], _winrt.winrt_base):
    ...
    def read_async(buffer: IBuffer, count: int, options: InputStreamOptions) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[IBuffer, int]:
        ...
    def close() -> None:
        ...

class FileOutputStream(IOutputStream, bleak_winrt.windows.foundation.IClosable, typing.ContextManager[FileOutputStream], _winrt.winrt_base):
    ...
    def write_async(buffer: IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...
    def close() -> None:
        ...

class FileRandomAccessStream(IRandomAccessStream, IOutputStream, bleak_winrt.windows.foundation.IClosable, IInputStream, typing.ContextManager[FileRandomAccessStream], _winrt.winrt_base):
    ...
    size: int
    can_read: bool
    can_write: bool
    position: int
    def get_input_stream_at(position: int) -> IInputStream:
        ...
    def get_output_stream_at(position: int) -> IOutputStream:
        ...
    def seek(position: int) -> None:
        ...
    def clone_stream() -> IRandomAccessStream:
        ...
    def close() -> None:
        ...
    def read_async(buffer: IBuffer, count: int, options: InputStreamOptions) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[IBuffer, int]:
        ...
    def write_async(buffer: IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...
    def open_async(file_path: str, access_mode: bleak_winrt.windows.storage.FileAccessMode) -> bleak_winrt.windows.foundation.IAsyncOperation[IRandomAccessStream]:
        ...
    def open_async(file_path: str, access_mode: bleak_winrt.windows.storage.FileAccessMode, sharing_options: bleak_winrt.windows.storage.StorageOpenOptions, open_disposition: FileOpenDisposition) -> bleak_winrt.windows.foundation.IAsyncOperation[IRandomAccessStream]:
        ...
    def open_transacted_write_async(file_path: str) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.storage.StorageStreamTransaction]:
        ...
    def open_transacted_write_async(file_path: str, open_options: bleak_winrt.windows.storage.StorageOpenOptions, open_disposition: FileOpenDisposition) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.storage.StorageStreamTransaction]:
        ...
    def open_for_user_async(user: bleak_winrt.windows.system.User, file_path: str, access_mode: bleak_winrt.windows.storage.FileAccessMode) -> bleak_winrt.windows.foundation.IAsyncOperation[IRandomAccessStream]:
        ...
    def open_for_user_async(user: bleak_winrt.windows.system.User, file_path: str, access_mode: bleak_winrt.windows.storage.FileAccessMode, sharing_options: bleak_winrt.windows.storage.StorageOpenOptions, open_disposition: FileOpenDisposition) -> bleak_winrt.windows.foundation.IAsyncOperation[IRandomAccessStream]:
        ...
    def open_transacted_write_for_user_async(user: bleak_winrt.windows.system.User, file_path: str) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.storage.StorageStreamTransaction]:
        ...
    def open_transacted_write_for_user_async(user: bleak_winrt.windows.system.User, file_path: str, open_options: bleak_winrt.windows.storage.StorageOpenOptions, open_disposition: FileOpenDisposition) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.storage.StorageStreamTransaction]:
        ...

class InMemoryRandomAccessStream(IRandomAccessStream, IOutputStream, bleak_winrt.windows.foundation.IClosable, IInputStream, typing.ContextManager[InMemoryRandomAccessStream], _winrt.winrt_base):
    ...
    size: int
    can_read: bool
    can_write: bool
    position: int
    def get_input_stream_at(position: int) -> IInputStream:
        ...
    def get_output_stream_at(position: int) -> IOutputStream:
        ...
    def seek(position: int) -> None:
        ...
    def clone_stream() -> IRandomAccessStream:
        ...
    def close() -> None:
        ...
    def read_async(buffer: IBuffer, count: int, options: InputStreamOptions) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[IBuffer, int]:
        ...
    def write_async(buffer: IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...

class InputStreamOverStream(IInputStream, bleak_winrt.windows.foundation.IClosable, typing.ContextManager[InputStreamOverStream], _winrt.winrt_base):
    ...
    def read_async(buffer: IBuffer, count: int, options: InputStreamOptions) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[IBuffer, int]:
        ...
    def close() -> None:
        ...

class OutputStreamOverStream(IOutputStream, bleak_winrt.windows.foundation.IClosable, typing.ContextManager[OutputStreamOverStream], _winrt.winrt_base):
    ...
    def write_async(buffer: IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...
    def close() -> None:
        ...

class RandomAccessStream(_winrt.winrt_base):
    ...
    def copy_async(source: IInputStream, destination: IOutputStream) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def copy_async(source: IInputStream, destination: IOutputStream, bytes_to_copy: int) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def copy_and_close_async(source: IInputStream, destination: IOutputStream) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...

class RandomAccessStreamOverStream(IRandomAccessStream, IOutputStream, bleak_winrt.windows.foundation.IClosable, IInputStream, typing.ContextManager[RandomAccessStreamOverStream], _winrt.winrt_base):
    ...
    size: int
    can_read: bool
    can_write: bool
    position: int
    def get_input_stream_at(position: int) -> IInputStream:
        ...
    def get_output_stream_at(position: int) -> IOutputStream:
        ...
    def seek(position: int) -> None:
        ...
    def clone_stream() -> IRandomAccessStream:
        ...
    def close() -> None:
        ...
    def read_async(buffer: IBuffer, count: int, options: InputStreamOptions) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[IBuffer, int]:
        ...
    def write_async(buffer: IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...

class RandomAccessStreamReference(IRandomAccessStreamReference, _winrt.winrt_base):
    ...
    def open_read_async() -> bleak_winrt.windows.foundation.IAsyncOperation[IRandomAccessStreamWithContentType]:
        ...
    def create_from_file(file: bleak_winrt.windows.storage.IStorageFile) -> RandomAccessStreamReference:
        ...
    def create_from_uri(uri: bleak_winrt.windows.foundation.Uri) -> RandomAccessStreamReference:
        ...
    def create_from_stream(stream: IRandomAccessStream) -> RandomAccessStreamReference:
        ...

class IBuffer(_winrt.winrt_base):
    ...
    capacity: int
    length: int

class IContentTypeProvider(_winrt.winrt_base):
    ...
    content_type: str

class IDataReader(_winrt.winrt_base):
    ...
    byte_order: ByteOrder
    input_stream_options: InputStreamOptions
    unconsumed_buffer_length: int
    unicode_encoding: UnicodeEncoding
    def read_byte() -> int:
        ...
    def read_bytes(value_size: int) -> typing.List[int]:
        ...
    def read_buffer(length: int) -> IBuffer:
        ...
    def read_boolean() -> bool:
        ...
    def read_guid() -> uuid.UUID:
        ...
    def read_int16() -> int:
        ...
    def read_int32() -> int:
        ...
    def read_int64() -> int:
        ...
    def read_uint16() -> int:
        ...
    def read_uint32() -> int:
        ...
    def read_uint64() -> int:
        ...
    def read_single() -> float:
        ...
    def read_double() -> float:
        ...
    def read_string(code_unit_count: int) -> str:
        ...
    def read_date_time() -> bleak_winrt.windows.foundation.DateTime:
        ...
    def read_time_span() -> bleak_winrt.windows.foundation.TimeSpan:
        ...
    def load_async(count: int) -> DataReaderLoadOperation:
        ...
    def detach_buffer() -> IBuffer:
        ...
    def detach_stream() -> IInputStream:
        ...

class IDataWriter(_winrt.winrt_base):
    ...
    byte_order: ByteOrder
    unicode_encoding: UnicodeEncoding
    unstored_buffer_length: int
    def write_byte(value: int) -> None:
        ...
    def write_bytes(value: typing.Sequence[int]) -> None:
        ...
    def write_buffer(buffer: IBuffer) -> None:
        ...
    def write_buffer(buffer: IBuffer, start: int, count: int) -> None:
        ...
    def write_boolean(value: bool) -> None:
        ...
    def write_guid(value: uuid.UUID) -> None:
        ...
    def write_int16(value: int) -> None:
        ...
    def write_int32(value: int) -> None:
        ...
    def write_int64(value: int) -> None:
        ...
    def write_uint16(value: int) -> None:
        ...
    def write_uint32(value: int) -> None:
        ...
    def write_uint64(value: int) -> None:
        ...
    def write_single(value: float) -> None:
        ...
    def write_double(value: float) -> None:
        ...
    def write_date_time(value: bleak_winrt.windows.foundation.DateTime) -> None:
        ...
    def write_time_span(value: bleak_winrt.windows.foundation.TimeSpan) -> None:
        ...
    def write_string(value: str) -> int:
        ...
    def measure_string(value: str) -> int:
        ...
    def store_async() -> DataWriterStoreOperation:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...
    def detach_buffer() -> IBuffer:
        ...
    def detach_stream() -> IOutputStream:
        ...

class IInputStream(bleak_winrt.windows.foundation.IClosable, typing.ContextManager[IInputStream], _winrt.winrt_base):
    ...
    def read_async(buffer: IBuffer, count: int, options: InputStreamOptions) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[IBuffer, int]:
        ...
    def close() -> None:
        ...

class IInputStreamReference(_winrt.winrt_base):
    ...
    def open_sequential_read_async() -> bleak_winrt.windows.foundation.IAsyncOperation[IInputStream]:
        ...

class IOutputStream(bleak_winrt.windows.foundation.IClosable, typing.ContextManager[IOutputStream], _winrt.winrt_base):
    ...
    def write_async(buffer: IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...
    def close() -> None:
        ...

class IPropertySetSerializer(_winrt.winrt_base):
    ...
    def serialize(property_set: bleak_winrt.windows.foundation.collections.IPropertySet) -> IBuffer:
        ...
    def deserialize(property_set: bleak_winrt.windows.foundation.collections.IPropertySet, buffer: IBuffer) -> None:
        ...

class IRandomAccessStream(bleak_winrt.windows.foundation.IClosable, IInputStream, IOutputStream, typing.ContextManager[IRandomAccessStream], _winrt.winrt_base):
    ...
    can_read: bool
    can_write: bool
    position: int
    size: int
    def get_input_stream_at(position: int) -> IInputStream:
        ...
    def get_output_stream_at(position: int) -> IOutputStream:
        ...
    def seek(position: int) -> None:
        ...
    def clone_stream() -> IRandomAccessStream:
        ...
    def close() -> None:
        ...
    def read_async(buffer: IBuffer, count: int, options: InputStreamOptions) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[IBuffer, int]:
        ...
    def write_async(buffer: IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...

class IRandomAccessStreamReference(_winrt.winrt_base):
    ...
    def open_read_async() -> bleak_winrt.windows.foundation.IAsyncOperation[IRandomAccessStreamWithContentType]:
        ...

class IRandomAccessStreamWithContentType(IRandomAccessStream, bleak_winrt.windows.foundation.IClosable, IInputStream, IOutputStream, IContentTypeProvider, typing.ContextManager[IRandomAccessStreamWithContentType], _winrt.winrt_base):
    ...
    can_read: bool
    can_write: bool
    position: int
    size: int
    content_type: str
    def get_input_stream_at(position: int) -> IInputStream:
        ...
    def get_output_stream_at(position: int) -> IOutputStream:
        ...
    def seek(position: int) -> None:
        ...
    def clone_stream() -> IRandomAccessStream:
        ...
    def close() -> None:
        ...
    def read_async(buffer: IBuffer, count: int, options: InputStreamOptions) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[IBuffer, int]:
        ...
    def write_async(buffer: IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum

import bleak_winrt

_ns_module = bleak_winrt._import_ns_module("Windows.Devices.Bluetooth.Background")

try:
    import bleak_winrt.windows.devices.bluetooth
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.advertisement
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.genericattributeprofile
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.rfcomm
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.networking.sockets
except Exception:
    pass

try:
    import bleak_winrt.windows.storage.streams
except Exception:
    pass

class BluetoothEventTriggeringMode(enum.IntEnum):
    SERIAL = 0
    BATCH = 1
    KEEP_LATEST = 2

BluetoothLEAdvertisementPublisherTriggerDetails = _ns_module.BluetoothLEAdvertisementPublisherTriggerDetails
BluetoothLEAdvertisementWatcherTriggerDetails = _ns_module.BluetoothLEAdvertisementWatcherTriggerDetails
GattCharacteristicNotificationTriggerDetails = _ns_module.GattCharacteristicNotificationTriggerDetails
GattServiceProviderConnection = _ns_module.GattServiceProviderConnection
GattServiceProviderTriggerDetails = _ns_module.GattServiceProviderTriggerDetails
RfcommConnectionTriggerDetails = _ns_module.RfcommConnectionTriggerDetails
RfcommInboundConnectionInformation = _ns_module.RfcommInboundConnectionInformation
RfcommOutboundConnectionInformation = _ns_module.RfcommOutboundConnectionInformation



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum
import typing
import uuid

import bleak_winrt._winrt as _winrt
try:
    import bleak_winrt.windows.applicationmodel.background
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.security.credentials
except Exception:
    pass

try:
    import bleak_winrt.windows.storage.streams
except Exception:
    pass

try:
    import bleak_winrt.windows.ui
except Exception:
    pass

try:
    import bleak_winrt.windows.ui.popups
except Exception:
    pass

class DeviceAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

class DeviceClass(enum.IntEnum):
    ALL = 0
    AUDIO_CAPTURE = 1
    AUDIO_RENDER = 2
    PORTABLE_STORAGE_DEVICE = 3
    VIDEO_CAPTURE = 4
    IMAGE_SCANNER = 5
    LOCATION = 6

class DeviceInformationKind(enum.IntEnum):
    UNKNOWN = 0
    DEVICE_INTERFACE = 1
    DEVICE_CONTAINER = 2
    DEVICE = 3
    DEVICE_INTERFACE_CLASS = 4
    ASSOCIATION_ENDPOINT = 5
    ASSOCIATION_ENDPOINT_CONTAINER = 6
    ASSOCIATION_ENDPOINT_SERVICE = 7
    DEVICE_PANEL = 8

class DevicePairingKinds(enum.IntFlag):
    NONE = 0
    CONFIRM_ONLY = 0x1
    DISPLAY_PIN = 0x2
    PROVIDE_PIN = 0x4
    CONFIRM_PIN_MATCH = 0x8
    PROVIDE_PASSWORD_CREDENTIAL = 0x10

class DevicePairingProtectionLevel(enum.IntEnum):
    DEFAULT = 0
    NONE = 1
    ENCRYPTION = 2
    ENCRYPTION_AND_AUTHENTICATION = 3

class DevicePairingResultStatus(enum.IntEnum):
    PAIRED = 0
    NOT_READY_TO_PAIR = 1
    NOT_PAIRED = 2
    ALREADY_PAIRED = 3
    CONNECTION_REJECTED = 4
    TOO_MANY_CONNECTIONS = 5
    HARDWARE_FAILURE = 6
    AUTHENTICATION_TIMEOUT = 7
    AUTHENTICATION_NOT_ALLOWED = 8
    AUTHENTICATION_FAILURE = 9
    NO_SUPPORTED_PROFILES = 10
    PROTECTION_LEVEL_COULD_NOT_BE_MET = 11
    ACCESS_DENIED = 12
    INVALID_CEREMONY_DATA = 13
    PAIRING_CANCELED = 14
    OPERATION_ALREADY_IN_PROGRESS = 15
    REQUIRED_HANDLER_NOT_REGISTERED = 16
    REJECTED_BY_HANDLER = 17
    REMOTE_DEVICE_HAS_ASSOCIATION = 18
    FAILED = 19

class DevicePickerDisplayStatusOptions(enum.IntFlag):
    NONE = 0
    SHOW_PROGRESS = 0x1
    SHOW_DISCONNECT_BUTTON = 0x2
    SHOW_RETRY_BUTTON = 0x4

class DeviceUnpairingResultStatus(enum.IntEnum):
    UNPAIRED = 0
    ALREADY_UNPAIRED = 1
    OPERATION_ALREADY_IN_PROGRESS = 2
    ACCESS_DENIED = 3
    FAILED = 4

class DeviceWatcherEventKind(enum.IntEnum):
    ADD = 0
    UPDATE = 1
    REMOVE = 2

class DeviceWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class Panel(enum.IntEnum):
    UNKNOWN = 0
    FRONT = 1
    BACK = 2
    TOP = 3
    BOTTOM = 4
    LEFT = 5
    RIGHT = 6

class DeviceAccessChangedEventArgs(_winrt.winrt_base):
    ...
    status: DeviceAccessStatus
    id: str

class DeviceAccessInformation(_winrt.winrt_base):
    ...
    current_status: DeviceAccessStatus
    def create_from_id(device_id: str) -> DeviceAccessInformation:
        ...
    def create_from_device_class_id(device_class_id: uuid.UUID) -> DeviceAccessInformation:
        ...
    def create_from_device_class(device_class: DeviceClass) -> DeviceAccessInformation:
        ...
    def add_access_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[DeviceAccessInformation, DeviceAccessChangedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_access_changed(cookie: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class DeviceConnectionChangeTriggerDetails(_winrt.winrt_base):
    ...
    device_id: str

class DeviceDisconnectButtonClickedEventArgs(_winrt.winrt_base):
    ...
    device: DeviceInformation

class DeviceInformation(_winrt.winrt_base):
    ...
    enclosure_location: EnclosureLocation
    id: str
    is_default: bool
    is_enabled: bool
    name: str
    properties: bleak_winrt.windows.foundation.collections.IMapView[str, _winrt.winrt_base]
    kind: DeviceInformationKind
    pairing: DeviceInformationPairing
    def update(update_info: DeviceInformationUpdate) -> None:
        ...
    def get_thumbnail_async() -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceThumbnail]:
        ...
    def get_glyph_thumbnail_async() -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceThumbnail]:
        ...
    def get_aqs_filter_from_device_class(device_class: DeviceClass) -> str:
        ...
    def create_from_id_async(device_id: str, additional_properties: bleak_winrt.windows.foundation.collections.IIterable[str], kind: DeviceInformationKind) -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformation]:
        ...
    def find_all_async(aqs_filter: str, additional_properties: bleak_winrt.windows.foundation.collections.IIterable[str], kind: DeviceInformationKind) -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformationCollection]:
        ...
    def create_watcher(aqs_filter: str, additional_properties: bleak_winrt.windows.foundation.collections.IIterable[str], kind: DeviceInformationKind) -> DeviceWatcher:
        ...
    def create_from_id_async(device_id: str) -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformation]:
        ...
    def create_from_id_async(device_id: str, additional_properties: bleak_winrt.windows.foundation.collections.IIterable[str]) -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformation]:
        ...
    def find_all_async() -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformationCollection]:
        ...
    def find_all_async(device_class: DeviceClass) -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformationCollection]:
        ...
    def find_all_async(aqs_filter: str) -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformationCollection]:
        ...
    def find_all_async(aqs_filter: str, additional_properties: bleak_winrt.windows.foundation.collections.IIterable[str]) -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformationCollection]:
        ...
    def create_watcher() -> DeviceWatcher:
        ...
    def create_watcher(device_class: DeviceClass) -> DeviceWatcher:
        ...
    def create_watcher(aqs_filter: str) -> DeviceWatcher:
        ...
    def create_watcher(aqs_filter: str, additional_properties: bleak_winrt.windows.foundation.collections.IIterable[str]) -> DeviceWatcher:
        ...

class DeviceInformationCollection(bleak_winrt.windows.foundation.collections.IVectorView[DeviceInformation], bleak_winrt.windows.foundation.collections.IIterable[DeviceInformation], _winrt.winrt_base):
    ...
    size: int
    def get_at(index: int) -> DeviceInformation:
        ...
    def index_of(value: DeviceInformation) -> typing.Tuple[bool, int]:
        ...
    def get_many(start_index: int, items_size: int) -> typing.Tuple[int, typing.List[DeviceInformation]]:
        ...
    def first() -> bleak_winrt.windows.foundation.collections.IIterator[DeviceInformation]:
        ...

class DeviceInformationCustomPairing(_winrt.winrt_base):
    ...
    def pair_async(pairing_kinds_supported: DevicePairingKinds) -> bleak_winrt.windows.foundation.IAsyncOperation[DevicePairingResult]:
        ...
    def pair_async(pairing_kinds_supported: DevicePairingKinds, min_protection_level: DevicePairingProtectionLevel) -> bleak_winrt.windows.foundation.IAsyncOperation[DevicePairingResult]:
        ...
    def pair_async(pairing_kinds_supported: DevicePairingKinds, min_protection_level: DevicePairingProtectionLevel, device_pairing_settings: IDevicePairingSettings) -> bleak_winrt.windows.foundation.IAsyncOperation[DevicePairingResult]:
        ...
    def add_pairing_requested(handler: bleak_winrt.windows.foundation.TypedEventHandler[DeviceInformationCustomPairing, DevicePairingRequestedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_pairing_requested(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class DeviceInformationPairing(_winrt.winrt_base):
    ...
    can_pair: bool
    is_paired: bool
    custom: DeviceInformationCustomPairing
    protection_level: DevicePairingProtectionLevel
    def pair_async() -> bleak_winrt.windows.foundation.IAsyncOperation[DevicePairingResult]:
        ...
    def pair_async(min_protection_level: DevicePairingProtectionLevel) -> bleak_winrt.windows.foundation.IAsyncOperation[DevicePairingResult]:
        ...
    def pair_async(min_protection_level: DevicePairingProtectionLevel, device_pairing_settings: IDevicePairingSettings) -> bleak_winrt.windows.foundation.IAsyncOperation[DevicePairingResult]:
        ...
    def unpair_async() -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceUnpairingResult]:
        ...
    def try_register_for_all_inbound_pairing_requests_with_protection_level(pairing_kinds_supported: DevicePairingKinds, min_protection_level: DevicePairingProtectionLevel) -> bool:
        ...
    def try_register_for_all_inbound_pairing_requests(pairing_kinds_supported: DevicePairingKinds) -> bool:
        ...

class DeviceInformationUpdate(_winrt.winrt_base):
    ...
    id: str
    properties: bleak_winrt.windows.foundation.collections.IMapView[str, _winrt.winrt_base]
    kind: DeviceInformationKind

class DevicePairingRequestedEventArgs(_winrt.winrt_base):
    ...
    device_information: DeviceInformation
    pairing_kind: DevicePairingKinds
    pin: str
    def accept() -> None:
        ...
    def accept(pin: str) -> None:
        ...
    def get_deferral() -> bleak_winrt.windows.foundation.Deferral:
        ...
    def accept_with_password_credential(password_credential: bleak_winrt.windows.security.credentials.PasswordCredential) -> None:
        ...

class DevicePairingResult(_winrt.winrt_base):
    ...
    protection_level_used: DevicePairingProtectionLevel
    status: DevicePairingResultStatus

class DevicePicker(_winrt.winrt_base):
    ...
    appearance: DevicePickerAppearance
    filter: DevicePickerFilter
    requested_properties: bleak_winrt.windows.foundation.collections.IVector[str]
    def show(selection: bleak_winrt.windows.foundation.Rect) -> None:
        ...
    def show(selection: bleak_winrt.windows.foundation.Rect, placement: bleak_winrt.windows.ui.popups.Placement) -> None:
        ...
    def pick_single_device_async(selection: bleak_winrt.windows.foundation.Rect) -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformation]:
        ...
    def pick_single_device_async(selection: bleak_winrt.windows.foundation.Rect, placement: bleak_winrt.windows.ui.popups.Placement) -> bleak_winrt.windows.foundation.IAsyncOperation[DeviceInformation]:
        ...
    def hide() -> None:
        ...
    def set_display_status(device: DeviceInformation, status: str, options: DevicePickerDisplayStatusOptions) -> None:
        ...
    def add_device_picker_dismissed(handler: bleak_winrt.windows.foundation.TypedEventHandler[DevicePicker, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_device_picker_dismissed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_device_selected(handler: bleak_winrt.windows.foundation.TypedEventHandler[DevicePicker, DeviceSelectedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_device_selected(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_disconnect_button_clicked(handler: bleak_winrt.windows.foundation.TypedEventHandler[DevicePicker, DeviceDisconnectButtonClickedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_disconnect_button_clicked(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class DevicePickerAppearance(_winrt.winrt_base):
    ...
    title: str
    selected_foreground_color: bleak_winrt.windows.ui.Color
    selected_background_color: bleak_winrt.windows.ui.Color
    selected_accent_color: bleak_winrt.windows.ui.Color
    foreground_color: bleak_winrt.windows.ui.Color
    background_color: bleak_winrt.windows.ui.Color
    accent_color: bleak_winrt.windows.ui.Color

class DevicePickerFilter(_winrt.winrt_base):
    ...
    supported_device_classes: bleak_winrt.windows.foundation.collections.IVector[DeviceClass]
    supported_device_selectors: bleak_winrt.windows.foundation.collections.IVector[str]

class DeviceSelectedEventArgs(_winrt.winrt_base):
    ...
    selected_device: DeviceInformation

class DeviceThumbnail(bleak_winrt.windows.storage.streams.IRandomAccessStreamWithContentType, bleak_winrt.windows.storage.streams.IContentTypeProvider, bleak_winrt.windows.storage.streams.IRandomAccessStream, bleak_winrt.windows.storage.streams.IOutputStream, bleak_winrt.windows.foundation.IClosable, bleak_winrt.windows.storage.streams.IInputStream, typing.ContextManager[DeviceThumbnail], _winrt.winrt_base):
    ...
    content_type: str
    size: int
    can_read: bool
    can_write: bool
    position: int
    def get_input_stream_at(position: int) -> bleak_winrt.windows.storage.streams.IInputStream:
        ...
    def get_output_stream_at(position: int) -> bleak_winrt.windows.storage.streams.IOutputStream:
        ...
    def seek(position: int) -> None:
        ...
    def clone_stream() -> bleak_winrt.windows.storage.streams.IRandomAccessStream:
        ...
    def close() -> None:
        ...
    def read_async(buffer: bleak_winrt.windows.storage.streams.IBuffer, count: int, options: bleak_winrt.windows.storage.streams.InputStreamOptions) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[bleak_winrt.windows.storage.streams.IBuffer, int]:
        ...
    def write_async(buffer: bleak_winrt.windows.storage.streams.IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperationWithProgress[int, int]:
        ...
    def flush_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bool]:
        ...

class DeviceUnpairingResult(_winrt.winrt_base):
    ...
    status: DeviceUnpairingResultStatus

class DeviceWatcher(_winrt.winrt_base):
    ...
    status: DeviceWatcherStatus
    def start() -> None:
        ...
    def stop() -> None:
        ...
    def get_background_trigger(requested_event_kinds: bleak_winrt.windows.foundation.collections.IIterable[DeviceWatcherEventKind]) -> bleak_winrt.windows.applicationmodel.background.DeviceWatcherTrigger:
        ...
    def add_added(handler: bleak_winrt.windows.foundation.TypedEventHandler[DeviceWatcher, DeviceInformation]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_added(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_enumeration_completed(handler: bleak_winrt.windows.foundation.TypedEventHandler[DeviceWatcher, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_enumeration_completed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_removed(handler: bleak_winrt.windows.foundation.TypedEventHandler[DeviceWatcher, DeviceInformationUpdate]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_removed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_stopped(handler: bleak_winrt.windows.foundation.TypedEventHandler[DeviceWatcher, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_stopped(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_updated(handler: bleak_winrt.windows.foundation.TypedEventHandler[DeviceWatcher, DeviceInformationUpdate]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_updated(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class DeviceWatcherEvent(_winrt.winrt_base):
    ...
    device_information: DeviceInformation
    device_information_update: DeviceInformationUpdate
    kind: DeviceWatcherEventKind

class DeviceWatcherTriggerDetails(_winrt.winrt_base):
    ...
    device_watcher_events: bleak_winrt.windows.foundation.collections.IVectorView[DeviceWatcherEvent]

class EnclosureLocation(_winrt.winrt_base):
    ...
    in_dock: bool
    in_lid: bool
    panel: Panel
    rotation_angle_in_degrees_clockwise: int

class IDevicePairingSettings(_winrt.winrt_base):
    ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum
import typing
import uuid

import bleak_winrt._winrt as _winrt
try:
    import bleak_winrt.windows.devices.bluetooth
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.advertisement
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.genericattributeprofile
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.rfcomm
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.networking.sockets
except Exception:
    pass

try:
    import bleak_winrt.windows.storage.streams
except Exception:
    pass

class BluetoothEventTriggeringMode(enum.IntEnum):
    SERIAL = 0
    BATCH = 1
    KEEP_LATEST = 2

class BluetoothLEAdvertisementPublisherTriggerDetails(_winrt.winrt_base):
    ...
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    status: bleak_winrt.windows.devices.bluetooth.advertisement.BluetoothLEAdvertisementPublisherStatus
    selected_transmit_power_level_in_d_bm: bleak_winrt.windows.foundation.IReference[int]

class BluetoothLEAdvertisementWatcherTriggerDetails(_winrt.winrt_base):
    ...
    advertisements: bleak_winrt.windows.foundation.collections.IVectorView[bleak_winrt.windows.devices.bluetooth.advertisement.BluetoothLEAdvertisementReceivedEventArgs]
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    signal_strength_filter: bleak_winrt.windows.devices.bluetooth.BluetoothSignalStrengthFilter

class GattCharacteristicNotificationTriggerDetails(_winrt.winrt_base):
    ...
    characteristic: bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattCharacteristic
    value: bleak_winrt.windows.storage.streams.IBuffer
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    event_triggering_mode: BluetoothEventTriggeringMode
    value_changed_events: bleak_winrt.windows.foundation.collections.IVectorView[bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattValueChangedEventArgs]

class GattServiceProviderConnection(_winrt.winrt_base):
    ...
    service: bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattLocalService
    trigger_id: str
    all_services: bleak_winrt.windows.foundation.collections.IMapView[str, GattServiceProviderConnection]
    def start() -> None:
        ...

class GattServiceProviderTriggerDetails(_winrt.winrt_base):
    ...
    connection: GattServiceProviderConnection

class RfcommConnectionTriggerDetails(_winrt.winrt_base):
    ...
    incoming: bool
    remote_device: bleak_winrt.windows.devices.bluetooth.BluetoothDevice
    socket: bleak_winrt.windows.networking.sockets.StreamSocket

class RfcommInboundConnectionInformation(_winrt.winrt_base):
    ...
    service_capabilities: bleak_winrt.windows.devices.bluetooth.BluetoothServiceCapabilities
    sdp_record: bleak_winrt.windows.storage.streams.IBuffer
    local_service_id: bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommServiceId

class RfcommOutboundConnectionInformation(_winrt.winrt_base):
    ...
    remote_service_id: bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommServiceId




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum
import typing
import uuid

import bleak_winrt._winrt as _winrt
try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

class CollectionChange(enum.IntEnum):
    RESET = 0
    ITEM_INSERTED = 1
    ITEM_REMOVED = 2
    ITEM_CHANGED = 3

class PropertySet(IPropertySet, IObservableMap[str, _winrt.winrt_base], IMap[str, _winrt.winrt_base], IIterable[IKeyValuePair[str, _winrt.winrt_base]], _winrt.winrt_base):
    ...
    size: int
    def lookup(key: str) -> _winrt.winrt_base:
        ...
    def has_key(key: str) -> bool:
        ...
    def get_view() -> IMapView[str, _winrt.winrt_base]:
        ...
    def insert(key: str, value: _winrt.winrt_base) -> bool:
        ...
    def remove(key: str) -> None:
        ...
    def clear() -> None:
        ...
    def first() -> IIterator[IKeyValuePair[str, _winrt.winrt_base]]:
        ...
    def add_map_changed(vhnd: MapChangedEventHandler[str, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_map_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class StringMap(IMap[str, str], IIterable[IKeyValuePair[str, str]], IObservableMap[str, str], _winrt.winrt_base):
    ...
    size: int
    def lookup(key: str) -> str:
        ...
    def has_key(key: str) -> bool:
        ...
    def get_view() -> IMapView[str, str]:
        ...
    def insert(key: str, value: str) -> bool:
        ...
    def remove(key: str) -> None:
        ...
    def clear() -> None:
        ...
    def first() -> IIterator[IKeyValuePair[str, str]]:
        ...
    def add_map_changed(vhnd: MapChangedEventHandler[str, str]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_map_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class ValueSet(IPropertySet, IObservableMap[str, _winrt.winrt_base], IMap[str, _winrt.winrt_base], IIterable[IKeyValuePair[str, _winrt.winrt_base]], _winrt.winrt_base):
    ...
    size: int
    def lookup(key: str) -> _winrt.winrt_base:
        ...
    def has_key(key: str) -> bool:
        ...
    def get_view() -> IMapView[str, _winrt.winrt_base]:
        ...
    def insert(key: str, value: _winrt.winrt_base) -> bool:
        ...
    def remove(key: str) -> None:
        ...
    def clear() -> None:
        ...
    def first() -> IIterator[IKeyValuePair[str, _winrt.winrt_base]]:
        ...
    def add_map_changed(vhnd: MapChangedEventHandler[str, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_map_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

T = typing.TypeVar('T')

class IIterable(typing.Iterable[T], _winrt.winrt_base):
    ...
    def first() -> IIterator[T]:
        ...

T = typing.TypeVar('T')

class IIterator(typing.Iterator[T], _winrt.winrt_base):
    ...
    current: T
    has_current: bool
    def move_next() -> bool:
        ...
    def get_many(items_size: int) -> typing.Tuple[int, typing.List[T]]:
        ...

K = typing.TypeVar('K')

V = typing.TypeVar('V')

class IKeyValuePair(typing.Generic[K, V], _winrt.winrt_base):
    ...
    key: K
    value: V

K = typing.TypeVar('K')

class IMapChangedEventArgs(typing.Generic[K], _winrt.winrt_base):
    ...
    collection_change: CollectionChange
    key: K

K = typing.TypeVar('K')

V = typing.TypeVar('V')

class IMapView(IIterable[IKeyValuePair[K, V]], typing.Mapping[K, V], _winrt.winrt_base):
    ...
    size: int
    def lookup(key: K) -> V:
        ...
    def has_key(key: K) -> bool:
        ...
    def split() -> typing.Tuple[IMapView[K, V], IMapView[K, V]]:
        ...
    def first() -> IIterator[IKeyValuePair[K, V]]:
        ...

K = typing.TypeVar('K')

V = typing.TypeVar('V')

class IMap(IIterable[IKeyValuePair[K, V]], typing.Mapping[K, V], _winrt.winrt_base):
    ...
    size: int
    def lookup(key: K) -> V:
        ...
    def has_key(key: K) -> bool:
        ...
    def get_view() -> IMapView[K, V]:
        ...
    def insert(key: K, value: V) -> bool:
        ...
    def remove(key: K) -> None:
        ...
    def clear() -> None:
        ...
    def first() -> IIterator[IKeyValuePair[K, V]]:
        ...

K = typing.TypeVar('K')

V = typing.TypeVar('V')

class IObservableMap(IMap[K, V], _winrt.winrt_base):
    ...
    size: int
    def lookup(key: K) -> V:
        ...
    def has_key(key: K) -> bool:
        ...
    def get_view() -> IMapView[K, V]:
        ...
    def insert(key: K, value: V) -> bool:
        ...
    def remove(key: K) -> None:
        ...
    def clear() -> None:
        ...
    def first() -> IIterator[IKeyValuePair[K, V]]:
        ...
    def add_map_changed(vhnd: MapChangedEventHandler[K, V]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_map_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

T = typing.TypeVar('T')

class IObservableVector(IVector[T], _winrt.winrt_base):
    ...
    size: int
    def get_at(index: int) -> T:
        ...
    def get_view() -> IVectorView[T]:
        ...
    def index_of(value: T) -> typing.Tuple[bool, int]:
        ...
    def set_at(index: int, value: T) -> None:
        ...
    def insert_at(index: int, value: T) -> None:
        ...
    def remove_at(index: int) -> None:
        ...
    def append(value: T) -> None:
        ...
    def remove_at_end() -> None:
        ...
    def clear() -> None:
        ...
    def get_many(start_index: int, items_size: int) -> typing.Tuple[int, typing.List[T]]:
        ...
    def replace_all(items: typing.Sequence[T]) -> None:
        ...
    def first() -> IIterator[T]:
        ...
    def add_vector_changed(vhnd: VectorChangedEventHandler[T]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_vector_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class IPropertySet(IObservableMap[str, _winrt.winrt_base], IMap[str, _winrt.winrt_base], IIterable[IKeyValuePair[str, _winrt.winrt_base]], _winrt.winrt_base):
    ...
    size: int
    def lookup(key: str) -> _winrt.winrt_base:
        ...
    def has_key(key: str) -> bool:
        ...
    def get_view() -> IMapView[str, _winrt.winrt_base]:
        ...
    def insert(key: str, value: _winrt.winrt_base) -> bool:
        ...
    def remove(key: str) -> None:
        ...
    def clear() -> None:
        ...
    def first() -> IIterator[IKeyValuePair[str, _winrt.winrt_base]]:
        ...
    def add_map_changed(vhnd: MapChangedEventHandler[str, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_map_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class IVectorChangedEventArgs(_winrt.winrt_base):
    ...
    collection_change: CollectionChange
    index: int

T = typing.TypeVar('T')

class IVectorView(IIterable[T], typing.Sequence[T], _winrt.winrt_base):
    ...
    size: int
    def get_at(index: int) -> T:
        ...
    def index_of(value: T) -> typing.Tuple[bool, int]:
        ...
    def get_many(start_index: int, items_size: int) -> typing.Tuple[int, typing.List[T]]:
        ...
    def first() -> IIterator[T]:
        ...

T = typing.TypeVar('T')

class IVector(IIterable[T], typing.Sequence[T], _winrt.winrt_base):
    ...
    size: int
    def get_at(index: int) -> T:
        ...
    def get_view() -> IVectorView[T]:
        ...
    def index_of(value: T) -> typing.Tuple[bool, int]:
        ...
    def set_at(index: int, value: T) -> None:
        ...
    def insert_at(index: int, value: T) -> None:
        ...
    def remove_at(index: int) -> None:
        ...
    def append(value: T) -> None:
        ...
    def remove_at_end() -> None:
        ...
    def clear() -> None:
        ...
    def get_many(start_index: int, items_size: int) -> typing.Tuple[int, typing.List[T]]:
        ...
    def replace_all(items: typing.Sequence[T]) -> None:
        ...
    def first() -> IIterator[T]:
        ...

K = typing.TypeVar('K')

V = typing.TypeVar('V')

MapChangedEventHandler = typing.Callable[[IObservableMap[K, V], IMapChangedEventArgs[K]], None]

T = typing.TypeVar('T')

VectorChangedEventHandler = typing.Callable[[IObservableVector[T], IVectorChangedEventArgs], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum
import typing
import uuid

import bleak_winrt._winrt as _winrt
try:
    import bleak_winrt.windows.devices.bluetooth
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.enumeration
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.storage.streams
except Exception:
    pass

class GattCharacteristicProperties(enum.IntFlag):
    NONE = 0
    BROADCAST = 0x1
    READ = 0x2
    WRITE_WITHOUT_RESPONSE = 0x4
    WRITE = 0x8
    NOTIFY = 0x10
    INDICATE = 0x20
    AUTHENTICATED_SIGNED_WRITES = 0x40
    EXTENDED_PROPERTIES = 0x80
    RELIABLE_WRITES = 0x100
    WRITABLE_AUXILIARIES = 0x200

class GattClientCharacteristicConfigurationDescriptorValue(enum.IntEnum):
    NONE = 0
    NOTIFY = 1
    INDICATE = 2

class GattCommunicationStatus(enum.IntEnum):
    SUCCESS = 0
    UNREACHABLE = 1
    PROTOCOL_ERROR = 2
    ACCESS_DENIED = 3

class GattOpenStatus(enum.IntEnum):
    UNSPECIFIED = 0
    SUCCESS = 1
    ALREADY_OPENED = 2
    NOT_FOUND = 3
    SHARING_VIOLATION = 4
    ACCESS_DENIED = 5

class GattProtectionLevel(enum.IntEnum):
    PLAIN = 0
    AUTHENTICATION_REQUIRED = 1
    ENCRYPTION_REQUIRED = 2
    ENCRYPTION_AND_AUTHENTICATION_REQUIRED = 3

class GattRequestState(enum.IntEnum):
    PENDING = 0
    COMPLETED = 1
    CANCELED = 2

class GattServiceProviderAdvertisementStatus(enum.IntEnum):
    CREATED = 0
    STOPPED = 1
    STARTED = 2
    ABORTED = 3
    STARTED_WITHOUT_ALL_ADVERTISEMENT_DATA = 4

class GattSessionStatus(enum.IntEnum):
    CLOSED = 0
    ACTIVE = 1

class GattSharingMode(enum.IntEnum):
    UNSPECIFIED = 0
    EXCLUSIVE = 1
    SHARED_READ_ONLY = 2
    SHARED_READ_AND_WRITE = 3

class GattWriteOption(enum.IntEnum):
    WRITE_WITH_RESPONSE = 0
    WRITE_WITHOUT_RESPONSE = 1

class GattCharacteristic(_winrt.winrt_base):
    ...
    protection_level: GattProtectionLevel
    attribute_handle: int
    characteristic_properties: GattCharacteristicProperties
    presentation_formats: bleak_winrt.windows.foundation.collections.IVectorView[GattPresentationFormat]
    user_description: str
    uuid: uuid.UUID
    service: GattDeviceService
    def get_descriptors(descriptor_uuid: uuid.UUID) -> bleak_winrt.windows.foundation.collections.IVectorView[GattDescriptor]:
        ...
    def read_value_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattReadResult]:
        ...
    def read_value_async(cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattReadResult]:
        ...
    def write_value_async(value: bleak_winrt.windows.storage.streams.IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperation[GattCommunicationStatus]:
        ...
    def write_value_async(value: bleak_winrt.windows.storage.streams.IBuffer, write_option: GattWriteOption) -> bleak_winrt.windows.foundation.IAsyncOperation[GattCommunicationStatus]:
        ...
    def read_client_characteristic_configuration_descriptor_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattReadClientCharacteristicConfigurationDescriptorResult]:
        ...
    def write_client_characteristic_configuration_descriptor_async(client_characteristic_configuration_descriptor_value: GattClientCharacteristicConfigurationDescriptorValue) -> bleak_winrt.windows.foundation.IAsyncOperation[GattCommunicationStatus]:
        ...
    def get_all_descriptors() -> bleak_winrt.windows.foundation.collections.IVectorView[GattDescriptor]:
        ...
    def get_descriptors_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattDescriptorsResult]:
        ...
    def get_descriptors_async(cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattDescriptorsResult]:
        ...
    def get_descriptors_for_uuid_async(descriptor_uuid: uuid.UUID) -> bleak_winrt.windows.foundation.IAsyncOperation[GattDescriptorsResult]:
        ...
    def get_descriptors_for_uuid_async(descriptor_uuid: uuid.UUID, cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattDescriptorsResult]:
        ...
    def write_value_with_result_async(value: bleak_winrt.windows.storage.streams.IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperation[GattWriteResult]:
        ...
    def write_value_with_result_async(value: bleak_winrt.windows.storage.streams.IBuffer, write_option: GattWriteOption) -> bleak_winrt.windows.foundation.IAsyncOperation[GattWriteResult]:
        ...
    def write_client_characteristic_configuration_descriptor_with_result_async(client_characteristic_configuration_descriptor_value: GattClientCharacteristicConfigurationDescriptorValue) -> bleak_winrt.windows.foundation.IAsyncOperation[GattWriteResult]:
        ...
    def convert_short_id_to_uuid(short_id: int) -> uuid.UUID:
        ...
    def add_value_changed(value_changed_handler: bleak_winrt.windows.foundation.TypedEventHandler[GattCharacteristic, GattValueChangedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_value_changed(value_changed_event_cookie: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class GattCharacteristicUuids(_winrt.winrt_base):
    ...
    heart_rate_measurement: uuid.UUID
    battery_level: uuid.UUID
    blood_pressure_feature: uuid.UUID
    blood_pressure_measurement: uuid.UUID
    body_sensor_location: uuid.UUID
    csc_feature: uuid.UUID
    csc_measurement: uuid.UUID
    glucose_feature: uuid.UUID
    glucose_measurement: uuid.UUID
    glucose_measurement_context: uuid.UUID
    heart_rate_control_point: uuid.UUID
    intermediate_cuff_pressure: uuid.UUID
    intermediate_temperature: uuid.UUID
    measurement_interval: uuid.UUID
    record_access_control_point: uuid.UUID
    rsc_feature: uuid.UUID
    rsc_measurement: uuid.UUID
    s_c_control_point: uuid.UUID
    sensor_location: uuid.UUID
    temperature_measurement: uuid.UUID
    temperature_type: uuid.UUID
    gap_peripheral_preferred_connection_parameters: uuid.UUID
    gap_peripheral_privacy_flag: uuid.UUID
    gap_reconnection_address: uuid.UUID
    gatt_service_changed: uuid.UUID
    hardware_revision_string: uuid.UUID
    hid_control_point: uuid.UUID
    hid_information: uuid.UUID
    ieee1107320601_regulatory_certification_data_list: uuid.UUID
    ln_control_point: uuid.UUID
    ln_feature: uuid.UUID
    local_time_information: uuid.UUID
    location_and_speed: uuid.UUID
    manufacturer_name_string: uuid.UUID
    model_number_string: uuid.UUID
    navigation: uuid.UUID
    new_alert: uuid.UUID
    pnp_id: uuid.UUID
    position_quality: uuid.UUID
    protocol_mode: uuid.UUID
    cycling_power_feature: uuid.UUID
    report: uuid.UUID
    report_map: uuid.UUID
    ringer_control_point: uuid.UUID
    ringer_setting: uuid.UUID
    scan_interval_window: uuid.UUID
    scan_refresh: uuid.UUID
    serial_number_string: uuid.UUID
    software_revision_string: uuid.UUID
    support_unread_alert_category: uuid.UUID
    supported_new_alert_category: uuid.UUID
    system_id: uuid.UUID
    time_accuracy: uuid.UUID
    time_source: uuid.UUID
    time_update_control_point: uuid.UUID
    time_update_state: uuid.UUID
    time_with_dst: uuid.UUID
    time_zone: uuid.UUID
    tx_power_level: uuid.UUID
    unread_alert_status: uuid.UUID
    alert_category_id: uuid.UUID
    alert_category_id_bit_mask: uuid.UUID
    alert_level: uuid.UUID
    alert_notification_control_point: uuid.UUID
    alert_status: uuid.UUID
    boot_keyboard_input_report: uuid.UUID
    boot_keyboard_output_report: uuid.UUID
    boot_mouse_input_report: uuid.UUID
    current_time: uuid.UUID
    cycling_power_control_point: uuid.UUID
    reference_time_information: uuid.UUID
    cycling_power_measurement: uuid.UUID
    cycling_power_vector: uuid.UUID
    date_time: uuid.UUID
    day_date_time: uuid.UUID
    day_of_week: uuid.UUID
    dst_offset: uuid.UUID
    exact_time256: uuid.UUID
    firmware_revision_string: uuid.UUID
    gap_appearance: uuid.UUID
    gap_device_name: uuid.UUID

class GattCharacteristicsResult(_winrt.winrt_base):
    ...
    characteristics: bleak_winrt.windows.foundation.collections.IVectorView[GattCharacteristic]
    protocol_error: bleak_winrt.windows.foundation.IReference[int]
    status: GattCommunicationStatus

class GattClientNotificationResult(_winrt.winrt_base):
    ...
    protocol_error: bleak_winrt.windows.foundation.IReference[int]
    status: GattCommunicationStatus
    subscribed_client: GattSubscribedClient
    bytes_sent: int

class GattDescriptor(_winrt.winrt_base):
    ...
    protection_level: GattProtectionLevel
    attribute_handle: int
    uuid: uuid.UUID
    def read_value_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattReadResult]:
        ...
    def read_value_async(cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattReadResult]:
        ...
    def write_value_async(value: bleak_winrt.windows.storage.streams.IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperation[GattCommunicationStatus]:
        ...
    def write_value_with_result_async(value: bleak_winrt.windows.storage.streams.IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperation[GattWriteResult]:
        ...
    def convert_short_id_to_uuid(short_id: int) -> uuid.UUID:
        ...

class GattDescriptorUuids(_winrt.winrt_base):
    ...
    characteristic_aggregate_format: uuid.UUID
    characteristic_extended_properties: uuid.UUID
    characteristic_presentation_format: uuid.UUID
    characteristic_user_description: uuid.UUID
    client_characteristic_configuration: uuid.UUID
    server_characteristic_configuration: uuid.UUID

class GattDescriptorsResult(_winrt.winrt_base):
    ...
    descriptors: bleak_winrt.windows.foundation.collections.IVectorView[GattDescriptor]
    protocol_error: bleak_winrt.windows.foundation.IReference[int]
    status: GattCommunicationStatus

class GattDeviceService(bleak_winrt.windows.foundation.IClosable, typing.ContextManager[GattDeviceService], _winrt.winrt_base):
    ...
    attribute_handle: int
    device_id: str
    uuid: uuid.UUID
    device: bleak_winrt.windows.devices.bluetooth.BluetoothLEDevice
    parent_services: bleak_winrt.windows.foundation.collections.IVectorView[GattDeviceService]
    device_access_information: bleak_winrt.windows.devices.enumeration.DeviceAccessInformation
    session: GattSession
    sharing_mode: GattSharingMode
    def get_characteristics(characteristic_uuid: uuid.UUID) -> bleak_winrt.windows.foundation.collections.IVectorView[GattCharacteristic]:
        ...
    def get_included_services(service_uuid: uuid.UUID) -> bleak_winrt.windows.foundation.collections.IVectorView[GattDeviceService]:
        ...
    def close() -> None:
        ...
    def get_all_characteristics() -> bleak_winrt.windows.foundation.collections.IVectorView[GattCharacteristic]:
        ...
    def get_all_included_services() -> bleak_winrt.windows.foundation.collections.IVectorView[GattDeviceService]:
        ...
    def request_access_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.enumeration.DeviceAccessStatus]:
        ...
    def open_async(sharing_mode: GattSharingMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattOpenStatus]:
        ...
    def get_characteristics_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattCharacteristicsResult]:
        ...
    def get_characteristics_async(cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattCharacteristicsResult]:
        ...
    def get_characteristics_for_uuid_async(characteristic_uuid: uuid.UUID) -> bleak_winrt.windows.foundation.IAsyncOperation[GattCharacteristicsResult]:
        ...
    def get_characteristics_for_uuid_async(characteristic_uuid: uuid.UUID, cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattCharacteristicsResult]:
        ...
    def get_included_services_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattDeviceServicesResult]:
        ...
    def get_included_services_async(cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattDeviceServicesResult]:
        ...
    def get_included_services_for_uuid_async(service_uuid: uuid.UUID) -> bleak_winrt.windows.foundation.IAsyncOperation[GattDeviceServicesResult]:
        ...
    def get_included_services_for_uuid_async(service_uuid: uuid.UUID, cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattDeviceServicesResult]:
        ...
    def from_id_async(device_id: str, sharing_mode: GattSharingMode) -> bleak_winrt.windows.foundation.IAsyncOperation[GattDeviceService]:
        ...
    def get_device_selector_for_bluetooth_device_id(bluetooth_device_id: bleak_winrt.windows.devices.bluetooth.BluetoothDeviceId) -> str:
        ...
    def get_device_selector_for_bluetooth_device_id(bluetooth_device_id: bleak_winrt.windows.devices.bluetooth.BluetoothDeviceId, cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> str:
        ...
    def get_device_selector_for_bluetooth_device_id_and_uuid(bluetooth_device_id: bleak_winrt.windows.devices.bluetooth.BluetoothDeviceId, service_uuid: uuid.UUID) -> str:
        ...
    def get_device_selector_for_bluetooth_device_id_and_uuid(bluetooth_device_id: bleak_winrt.windows.devices.bluetooth.BluetoothDeviceId, service_uuid: uuid.UUID, cache_mode: bleak_winrt.windows.devices.bluetooth.BluetoothCacheMode) -> str:
        ...
    def from_id_async(device_id: str) -> bleak_winrt.windows.foundation.IAsyncOperation[GattDeviceService]:
        ...
    def get_device_selector_from_uuid(service_uuid: uuid.UUID) -> str:
        ...
    def get_device_selector_from_short_id(service_short_id: int) -> str:
        ...
    def convert_short_id_to_uuid(short_id: int) -> uuid.UUID:
        ...

class GattDeviceServicesResult(_winrt.winrt_base):
    ...
    protocol_error: bleak_winrt.windows.foundation.IReference[int]
    services: bleak_winrt.windows.foundation.collections.IVectorView[GattDeviceService]
    status: GattCommunicationStatus

class GattLocalCharacteristic(_winrt.winrt_base):
    ...
    characteristic_properties: GattCharacteristicProperties
    descriptors: bleak_winrt.windows.foundation.collections.IVectorView[GattLocalDescriptor]
    presentation_formats: bleak_winrt.windows.foundation.collections.IVectorView[GattPresentationFormat]
    read_protection_level: GattProtectionLevel
    static_value: bleak_winrt.windows.storage.streams.IBuffer
    subscribed_clients: bleak_winrt.windows.foundation.collections.IVectorView[GattSubscribedClient]
    user_description: str
    uuid: uuid.UUID
    write_protection_level: GattProtectionLevel
    def create_descriptor_async(descriptor_uuid: uuid.UUID, parameters: GattLocalDescriptorParameters) -> bleak_winrt.windows.foundation.IAsyncOperation[GattLocalDescriptorResult]:
        ...
    def notify_value_async(value: bleak_winrt.windows.storage.streams.IBuffer) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.foundation.collections.IVectorView[GattClientNotificationResult]]:
        ...
    def notify_value_async(value: bleak_winrt.windows.storage.streams.IBuffer, subscribed_client: GattSubscribedClient) -> bleak_winrt.windows.foundation.IAsyncOperation[GattClientNotificationResult]:
        ...
    def add_read_requested(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattLocalCharacteristic, GattReadRequestedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_read_requested(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_subscribed_clients_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattLocalCharacteristic, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_subscribed_clients_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_write_requested(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattLocalCharacteristic, GattWriteRequestedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_write_requested(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class GattLocalCharacteristicParameters(_winrt.winrt_base):
    ...
    write_protection_level: GattProtectionLevel
    user_description: str
    static_value: bleak_winrt.windows.storage.streams.IBuffer
    read_protection_level: GattProtectionLevel
    characteristic_properties: GattCharacteristicProperties
    presentation_formats: bleak_winrt.windows.foundation.collections.IVector[GattPresentationFormat]

class GattLocalCharacteristicResult(_winrt.winrt_base):
    ...
    characteristic: GattLocalCharacteristic
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError

class GattLocalDescriptor(_winrt.winrt_base):
    ...
    read_protection_level: GattProtectionLevel
    static_value: bleak_winrt.windows.storage.streams.IBuffer
    uuid: uuid.UUID
    write_protection_level: GattProtectionLevel
    def add_read_requested(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattLocalDescriptor, GattReadRequestedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_read_requested(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_write_requested(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattLocalDescriptor, GattWriteRequestedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_write_requested(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class GattLocalDescriptorParameters(_winrt.winrt_base):
    ...
    write_protection_level: GattProtectionLevel
    static_value: bleak_winrt.windows.storage.streams.IBuffer
    read_protection_level: GattProtectionLevel

class GattLocalDescriptorResult(_winrt.winrt_base):
    ...
    descriptor: GattLocalDescriptor
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError

class GattLocalService(_winrt.winrt_base):
    ...
    characteristics: bleak_winrt.windows.foundation.collections.IVectorView[GattLocalCharacteristic]
    uuid: uuid.UUID
    def create_characteristic_async(characteristic_uuid: uuid.UUID, parameters: GattLocalCharacteristicParameters) -> bleak_winrt.windows.foundation.IAsyncOperation[GattLocalCharacteristicResult]:
        ...

class GattPresentationFormat(_winrt.winrt_base):
    ...
    description: int
    exponent: int
    format_type: int
    namespace: int
    unit: int
    bluetooth_sig_assigned_numbers: int
    def from_parts(format_type: int, exponent: int, unit: int, namespace_id: int, description: int) -> GattPresentationFormat:
        ...

class GattPresentationFormatTypes(_winrt.winrt_base):
    ...
    bit2: int
    boolean: int
    d_uint16: int
    float: int
    float32: int
    float64: int
    nibble: int
    s_float: int
    s_int12: int
    s_int128: int
    s_int16: int
    s_int24: int
    s_int32: int
    s_int48: int
    s_int64: int
    s_int8: int
    struct: int
    uint12: int
    uint128: int
    uint16: int
    uint24: int
    uint32: int
    uint48: int
    uint64: int
    uint8: int
    utf16: int
    utf8: int

class GattProtocolError(_winrt.winrt_base):
    ...
    attribute_not_found: int
    attribute_not_long: int
    insufficient_authentication: int
    insufficient_authorization: int
    insufficient_encryption: int
    insufficient_encryption_key_size: int
    insufficient_resources: int
    invalid_attribute_value_length: int
    invalid_handle: int
    invalid_offset: int
    invalid_pdu: int
    prepare_queue_full: int
    read_not_permitted: int
    request_not_supported: int
    unlikely_error: int
    unsupported_group_type: int
    write_not_permitted: int

class GattReadClientCharacteristicConfigurationDescriptorResult(_winrt.winrt_base):
    ...
    client_characteristic_configuration_descriptor: GattClientCharacteristicConfigurationDescriptorValue
    status: GattCommunicationStatus
    protocol_error: bleak_winrt.windows.foundation.IReference[int]

class GattReadRequest(_winrt.winrt_base):
    ...
    length: int
    offset: int
    state: GattRequestState
    def respond_with_value(value: bleak_winrt.windows.storage.streams.IBuffer) -> None:
        ...
    def respond_with_protocol_error(protocol_error: int) -> None:
        ...
    def add_state_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattReadRequest, GattRequestStateChangedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_state_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class GattReadRequestedEventArgs(_winrt.winrt_base):
    ...
    session: GattSession
    def get_deferral() -> bleak_winrt.windows.foundation.Deferral:
        ...
    def get_request_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattReadRequest]:
        ...

class GattReadResult(_winrt.winrt_base):
    ...
    status: GattCommunicationStatus
    value: bleak_winrt.windows.storage.streams.IBuffer
    protocol_error: bleak_winrt.windows.foundation.IReference[int]

class GattReliableWriteTransaction(_winrt.winrt_base):
    ...
    def write_value(characteristic: GattCharacteristic, value: bleak_winrt.windows.storage.streams.IBuffer) -> None:
        ...
    def commit_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattCommunicationStatus]:
        ...
    def commit_with_result_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattWriteResult]:
        ...

class GattRequestStateChangedEventArgs(_winrt.winrt_base):
    ...
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    state: GattRequestState

class GattServiceProvider(_winrt.winrt_base):
    ...
    advertisement_status: GattServiceProviderAdvertisementStatus
    service: GattLocalService
    def start_advertising() -> None:
        ...
    def start_advertising(parameters: GattServiceProviderAdvertisingParameters) -> None:
        ...
    def stop_advertising() -> None:
        ...
    def create_async(service_uuid: uuid.UUID) -> bleak_winrt.windows.foundation.IAsyncOperation[GattServiceProviderResult]:
        ...
    def add_advertisement_status_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattServiceProvider, GattServiceProviderAdvertisementStatusChangedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_advertisement_status_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class GattServiceProviderAdvertisementStatusChangedEventArgs(_winrt.winrt_base):
    ...
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    status: GattServiceProviderAdvertisementStatus

class GattServiceProviderAdvertisingParameters(_winrt.winrt_base):
    ...
    is_discoverable: bool
    is_connectable: bool
    service_data: bleak_winrt.windows.storage.streams.IBuffer

class GattServiceProviderResult(_winrt.winrt_base):
    ...
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    service_provider: GattServiceProvider

class GattServiceUuids(_winrt.winrt_base):
    ...
    battery: uuid.UUID
    blood_pressure: uuid.UUID
    cycling_speed_and_cadence: uuid.UUID
    generic_access: uuid.UUID
    generic_attribute: uuid.UUID
    glucose: uuid.UUID
    health_thermometer: uuid.UUID
    heart_rate: uuid.UUID
    running_speed_and_cadence: uuid.UUID
    alert_notification: uuid.UUID
    current_time: uuid.UUID
    cycling_power: uuid.UUID
    device_information: uuid.UUID
    human_interface_device: uuid.UUID
    immediate_alert: uuid.UUID
    link_loss: uuid.UUID
    location_and_navigation: uuid.UUID
    next_dst_change: uuid.UUID
    phone_alert_status: uuid.UUID
    reference_time_update: uuid.UUID
    scan_parameters: uuid.UUID
    tx_power: uuid.UUID

class GattSession(bleak_winrt.windows.foundation.IClosable, typing.ContextManager[GattSession], _winrt.winrt_base):
    ...
    maintain_connection: bool
    can_maintain_connection: bool
    device_id: bleak_winrt.windows.devices.bluetooth.BluetoothDeviceId
    max_pdu_size: int
    session_status: GattSessionStatus
    def close() -> None:
        ...
    def from_device_id_async(device_id: bleak_winrt.windows.devices.bluetooth.BluetoothDeviceId) -> bleak_winrt.windows.foundation.IAsyncOperation[GattSession]:
        ...
    def add_max_pdu_size_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattSession, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_max_pdu_size_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_session_status_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattSession, GattSessionStatusChangedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_session_status_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class GattSessionStatusChangedEventArgs(_winrt.winrt_base):
    ...
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    status: GattSessionStatus

class GattSubscribedClient(_winrt.winrt_base):
    ...
    max_notification_size: int
    session: GattSession
    def add_max_notification_size_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattSubscribedClient, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_max_notification_size_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class GattValueChangedEventArgs(_winrt.winrt_base):
    ...
    characteristic_value: bleak_winrt.windows.storage.streams.IBuffer
    timestamp: bleak_winrt.windows.foundation.DateTime

class GattWriteRequest(_winrt.winrt_base):
    ...
    offset: int
    option: GattWriteOption
    state: GattRequestState
    value: bleak_winrt.windows.storage.streams.IBuffer
    def respond() -> None:
        ...
    def respond_with_protocol_error(protocol_error: int) -> None:
        ...
    def add_state_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[GattWriteRequest, GattRequestStateChangedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_state_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class GattWriteRequestedEventArgs(_winrt.winrt_base):
    ...
    session: GattSession
    def get_deferral() -> bleak_winrt.windows.foundation.Deferral:
        ...
    def get_request_async() -> bleak_winrt.windows.foundation.IAsyncOperation[GattWriteRequest]:
        ...

class GattWriteResult(_winrt.winrt_base):
    ...
    protocol_error: bleak_winrt.windows.foundation.IReference[int]
    status: GattCommunicationStatus




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum
import typing
import uuid

import bleak_winrt._winrt as _winrt
try:
    import bleak_winrt.windows.devices.bluetooth.genericattributeprofile
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.rfcomm
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.enumeration
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.radios
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.networking
except Exception:
    pass

try:
    import bleak_winrt.windows.storage.streams
except Exception:
    pass

class BluetoothAddressType(enum.IntEnum):
    PUBLIC = 0
    RANDOM = 1
    UNSPECIFIED = 2

class BluetoothCacheMode(enum.IntEnum):
    CACHED = 0
    UNCACHED = 1

class BluetoothConnectionStatus(enum.IntEnum):
    DISCONNECTED = 0
    CONNECTED = 1

class BluetoothError(enum.IntEnum):
    SUCCESS = 0
    RADIO_NOT_AVAILABLE = 1
    RESOURCE_IN_USE = 2
    DEVICE_NOT_CONNECTED = 3
    OTHER_ERROR = 4
    DISABLED_BY_POLICY = 5
    NOT_SUPPORTED = 6
    DISABLED_BY_USER = 7
    CONSENT_REQUIRED = 8
    TRANSPORT_NOT_SUPPORTED = 9

class BluetoothLEPreferredConnectionParametersRequestStatus(enum.IntEnum):
    UNSPECIFIED = 0
    SUCCESS = 1
    DEVICE_NOT_AVAILABLE = 2
    ACCESS_DENIED = 3

class BluetoothMajorClass(enum.IntEnum):
    MISCELLANEOUS = 0
    COMPUTER = 1
    PHONE = 2
    NETWORK_ACCESS_POINT = 3
    AUDIO_VIDEO = 4
    PERIPHERAL = 5
    IMAGING = 6
    WEARABLE = 7
    TOY = 8
    HEALTH = 9

class BluetoothMinorClass(enum.IntEnum):
    UNCATEGORIZED = 0
    COMPUTER_DESKTOP = 1
    COMPUTER_SERVER = 2
    COMPUTER_LAPTOP = 3
    COMPUTER_HANDHELD = 4
    COMPUTER_PALM_SIZE = 5
    COMPUTER_WEARABLE = 6
    COMPUTER_TABLET = 7
    PHONE_CELLULAR = 1
    PHONE_CORDLESS = 2
    PHONE_SMART_PHONE = 3
    PHONE_WIRED = 4
    PHONE_ISDN = 5
    NETWORK_FULLY_AVAILABLE = 0
    NETWORK_USED01_TO17_PERCENT = 8
    NETWORK_USED17_TO33_PERCENT = 16
    NETWORK_USED33_TO50_PERCENT = 24
    NETWORK_USED50_TO67_PERCENT = 32
    NETWORK_USED67_TO83_PERCENT = 40
    NETWORK_USED83_TO99_PERCENT = 48
    NETWORK_NO_SERVICE_AVAILABLE = 56
    AUDIO_VIDEO_WEARABLE_HEADSET = 1
    AUDIO_VIDEO_HANDS_FREE = 2
    AUDIO_VIDEO_MICROPHONE = 4
    AUDIO_VIDEO_LOUDSPEAKER = 5
    AUDIO_VIDEO_HEADPHONES = 6
    AUDIO_VIDEO_PORTABLE_AUDIO = 7
    AUDIO_VIDEO_CAR_AUDIO = 8
    AUDIO_VIDEO_SET_TOP_BOX = 9
    AUDIO_VIDEO_HIFI_AUDIO_DEVICE = 10
    AUDIO_VIDEO_VCR = 11
    AUDIO_VIDEO_VIDEO_CAMERA = 12
    AUDIO_VIDEO_CAMCORDER = 13
    AUDIO_VIDEO_VIDEO_MONITOR = 14
    AUDIO_VIDEO_VIDEO_DISPLAY_AND_LOUDSPEAKER = 15
    AUDIO_VIDEO_VIDEO_CONFERENCING = 16
    AUDIO_VIDEO_GAMING_OR_TOY = 18
    PERIPHERAL_JOYSTICK = 1
    PERIPHERAL_GAMEPAD = 2
    PERIPHERAL_REMOTE_CONTROL = 3
    PERIPHERAL_SENSING = 4
    PERIPHERAL_DIGITIZER_TABLET = 5
    PERIPHERAL_CARD_READER = 6
    PERIPHERAL_DIGITAL_PEN = 7
    PERIPHERAL_HANDHELD_SCANNER = 8
    PERIPHERAL_HANDHELD_GESTURE = 9
    WEARABLE_WRISTWATCH = 1
    WEARABLE_PAGER = 2
    WEARABLE_JACKET = 3
    WEARABLE_HELMET = 4
    WEARABLE_GLASSES = 5
    TOY_ROBOT = 1
    TOY_VEHICLE = 2
    TOY_DOLL = 3
    TOY_CONTROLLER = 4
    TOY_GAME = 5
    HEALTH_BLOOD_PRESSURE_MONITOR = 1
    HEALTH_THERMOMETER = 2
    HEALTH_WEIGHING_SCALE = 3
    HEALTH_GLUCOSE_METER = 4
    HEALTH_PULSE_OXIMETER = 5
    HEALTH_HEART_RATE_MONITOR = 6
    HEALTH_HEALTH_DATA_DISPLAY = 7
    HEALTH_STEP_COUNTER = 8
    HEALTH_BODY_COMPOSITION_ANALYZER = 9
    HEALTH_PEAK_FLOW_MONITOR = 10
    HEALTH_MEDICATION_MONITOR = 11
    HEALTH_KNEE_PROSTHESIS = 12
    HEALTH_ANKLE_PROSTHESIS = 13
    HEALTH_GENERIC_HEALTH_MANAGER = 14
    HEALTH_PERSONAL_MOBILITY_DEVICE = 15

class BluetoothServiceCapabilities(enum.IntFlag):
    NONE = 0
    LIMITED_DISCOVERABLE_MODE = 0x1
    POSITIONING_SERVICE = 0x8
    NETWORKING_SERVICE = 0x10
    RENDERING_SERVICE = 0x20
    CAPTURING_SERVICE = 0x40
    OBJECT_TRANSFER_SERVICE = 0x80
    AUDIO_SERVICE = 0x100
    TELEPHONE_SERVICE = 0x200
    INFORMATION_SERVICE = 0x400

class BluetoothAdapter(_winrt.winrt_base):
    ...
    bluetooth_address: int
    device_id: str
    is_advertisement_offload_supported: bool
    is_central_role_supported: bool
    is_classic_supported: bool
    is_low_energy_supported: bool
    is_peripheral_role_supported: bool
    are_classic_secure_connections_supported: bool
    are_low_energy_secure_connections_supported: bool
    is_extended_advertising_supported: bool
    max_advertisement_data_length: int
    def get_radio_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.radios.Radio]:
        ...
    def get_device_selector() -> str:
        ...
    def from_id_async(device_id: str) -> bleak_winrt.windows.foundation.IAsyncOperation[BluetoothAdapter]:
        ...
    def get_default_async() -> bleak_winrt.windows.foundation.IAsyncOperation[BluetoothAdapter]:
        ...

class BluetoothClassOfDevice(_winrt.winrt_base):
    ...
    major_class: BluetoothMajorClass
    minor_class: BluetoothMinorClass
    raw_value: int
    service_capabilities: BluetoothServiceCapabilities
    def from_raw_value(raw_value: int) -> BluetoothClassOfDevice:
        ...
    def from_parts(major_class: BluetoothMajorClass, minor_class: BluetoothMinorClass, service_capabilities: BluetoothServiceCapabilities) -> BluetoothClassOfDevice:
        ...

class BluetoothDevice(bleak_winrt.windows.foundation.IClosable, typing.ContextManager[BluetoothDevice], _winrt.winrt_base):
    ...
    bluetooth_address: int
    class_of_device: BluetoothClassOfDevice
    connection_status: BluetoothConnectionStatus
    device_id: str
    host_name: bleak_winrt.windows.networking.HostName
    name: str
    rfcomm_services: bleak_winrt.windows.foundation.collections.IVectorView[bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommDeviceService]
    sdp_records: bleak_winrt.windows.foundation.collections.IVectorView[bleak_winrt.windows.storage.streams.IBuffer]
    device_information: bleak_winrt.windows.devices.enumeration.DeviceInformation
    device_access_information: bleak_winrt.windows.devices.enumeration.DeviceAccessInformation
    bluetooth_device_id: BluetoothDeviceId
    was_secure_connection_used_for_pairing: bool
    def request_access_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.enumeration.DeviceAccessStatus]:
        ...
    def get_rfcomm_services_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommDeviceServicesResult]:
        ...
    def get_rfcomm_services_async(cache_mode: BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommDeviceServicesResult]:
        ...
    def get_rfcomm_services_for_id_async(service_id: bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommServiceId) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommDeviceServicesResult]:
        ...
    def get_rfcomm_services_for_id_async(service_id: bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommServiceId, cache_mode: BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommDeviceServicesResult]:
        ...
    def close() -> None:
        ...
    def get_device_selector_from_pairing_state(pairing_state: bool) -> str:
        ...
    def get_device_selector_from_connection_status(connection_status: BluetoothConnectionStatus) -> str:
        ...
    def get_device_selector_from_device_name(device_name: str) -> str:
        ...
    def get_device_selector_from_bluetooth_address(bluetooth_address: int) -> str:
        ...
    def get_device_selector_from_class_of_device(class_of_device: BluetoothClassOfDevice) -> str:
        ...
    def from_id_async(device_id: str) -> bleak_winrt.windows.foundation.IAsyncOperation[BluetoothDevice]:
        ...
    def from_host_name_async(host_name: bleak_winrt.windows.networking.HostName) -> bleak_winrt.windows.foundation.IAsyncOperation[BluetoothDevice]:
        ...
    def from_bluetooth_address_async(address: int) -> bleak_winrt.windows.foundation.IAsyncOperation[BluetoothDevice]:
        ...
    def get_device_selector() -> str:
        ...
    def add_connection_status_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothDevice, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_connection_status_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_name_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothDevice, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_name_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_sdp_records_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothDevice, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_sdp_records_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class BluetoothDeviceId(_winrt.winrt_base):
    ...
    id: str
    is_classic_device: bool
    is_low_energy_device: bool
    def from_id(device_id: str) -> BluetoothDeviceId:
        ...

class BluetoothLEAppearance(_winrt.winrt_base):
    ...
    category: int
    raw_value: int
    sub_category: int
    def from_raw_value(raw_value: int) -> BluetoothLEAppearance:
        ...
    def from_parts(appearance_category: int, appearance_sub_category: int) -> BluetoothLEAppearance:
        ...

class BluetoothLEAppearanceCategories(_winrt.winrt_base):
    ...
    barcode_scanner: int
    blood_pressure: int
    clock: int
    computer: int
    cycling: int
    display: int
    eye_glasses: int
    glucose_meter: int
    heart_rate: int
    human_interface_device: int
    keyring: int
    media_player: int
    outdoor_sport_activity: int
    phone: int
    pulse_oximeter: int
    remote_control: int
    running_walking: int
    tag: int
    thermometer: int
    uncategorized: int
    watch: int
    weight_scale: int

class BluetoothLEAppearanceSubcategories(_winrt.winrt_base):
    ...
    barcode_scanner: int
    blood_pressure_arm: int
    blood_pressure_wrist: int
    card_reader: int
    cycling_cadence_sensor: int
    cycling_computer: int
    cycling_power_sensor: int
    cycling_speed_cadence_sensor: int
    cycling_speed_sensor: int
    digital_pen: int
    digitizer_tablet: int
    gamepad: int
    generic: int
    heart_rate_belt: int
    joystick: int
    keyboard: int
    location_display: int
    location_navigation_display: int
    location_navigation_pod: int
    location_pod: int
    mouse: int
    oximeter_fingertip: int
    oximeter_wrist_worn: int
    running_walking_in_shoe: int
    running_walking_on_hip: int
    running_walking_on_shoe: int
    sports_watch: int
    thermometer_ear: int

class BluetoothLEConnectionParameters(_winrt.winrt_base):
    ...
    connection_interval: int
    connection_latency: int
    link_timeout: int

class BluetoothLEConnectionPhy(_winrt.winrt_base):
    ...
    receive_info: BluetoothLEConnectionPhyInfo
    transmit_info: BluetoothLEConnectionPhyInfo

class BluetoothLEConnectionPhyInfo(_winrt.winrt_base):
    ...
    is_coded_phy: bool
    is_uncoded1_m_phy: bool
    is_uncoded2_m_phy: bool

class BluetoothLEDevice(bleak_winrt.windows.foundation.IClosable, typing.ContextManager[BluetoothLEDevice], _winrt.winrt_base):
    ...
    bluetooth_address: int
    connection_status: BluetoothConnectionStatus
    device_id: str
    gatt_services: bleak_winrt.windows.foundation.collections.IVectorView[bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattDeviceService]
    name: str
    appearance: BluetoothLEAppearance
    bluetooth_address_type: BluetoothAddressType
    device_information: bleak_winrt.windows.devices.enumeration.DeviceInformation
    device_access_information: bleak_winrt.windows.devices.enumeration.DeviceAccessInformation
    bluetooth_device_id: BluetoothDeviceId
    was_secure_connection_used_for_pairing: bool
    def get_gatt_service(service_uuid: uuid.UUID) -> bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattDeviceService:
        ...
    def request_access_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.enumeration.DeviceAccessStatus]:
        ...
    def get_gatt_services_async() -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattDeviceServicesResult]:
        ...
    def get_gatt_services_async(cache_mode: BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattDeviceServicesResult]:
        ...
    def get_gatt_services_for_uuid_async(service_uuid: uuid.UUID) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattDeviceServicesResult]:
        ...
    def get_gatt_services_for_uuid_async(service_uuid: uuid.UUID, cache_mode: BluetoothCacheMode) -> bleak_winrt.windows.foundation.IAsyncOperation[bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattDeviceServicesResult]:
        ...
    def get_connection_parameters() -> BluetoothLEConnectionParameters:
        ...
    def get_connection_phy() -> BluetoothLEConnectionPhy:
        ...
    def request_preferred_connection_parameters(preferred_connection_parameters: BluetoothLEPreferredConnectionParameters) -> BluetoothLEPreferredConnectionParametersRequest:
        ...
    def close() -> None:
        ...
    def get_device_selector_from_pairing_state(pairing_state: bool) -> str:
        ...
    def get_device_selector_from_connection_status(connection_status: BluetoothConnectionStatus) -> str:
        ...
    def get_device_selector_from_device_name(device_name: str) -> str:
        ...
    def get_device_selector_from_bluetooth_address(bluetooth_address: int) -> str:
        ...
    def get_device_selector_from_bluetooth_address(bluetooth_address: int, bluetooth_address_type: BluetoothAddressType) -> str:
        ...
    def get_device_selector_from_appearance(appearance: BluetoothLEAppearance) -> str:
        ...
    def from_bluetooth_address_async(bluetooth_address: int, bluetooth_address_type: BluetoothAddressType) -> bleak_winrt.windows.foundation.IAsyncOperation[BluetoothLEDevice]:
        ...
    def from_id_async(device_id: str) -> bleak_winrt.windows.foundation.IAsyncOperation[BluetoothLEDevice]:
        ...
    def from_bluetooth_address_async(bluetooth_address: int) -> bleak_winrt.windows.foundation.IAsyncOperation[BluetoothLEDevice]:
        ...
    def get_device_selector() -> str:
        ...
    def add_connection_status_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothLEDevice, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_connection_status_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_gatt_services_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothLEDevice, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_gatt_services_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_name_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothLEDevice, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_name_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_connection_parameters_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothLEDevice, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_connection_parameters_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_connection_phy_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothLEDevice, _winrt.winrt_base]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_connection_phy_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class BluetoothLEPreferredConnectionParameters(_winrt.winrt_base):
    ...
    connection_latency: int
    link_timeout: int
    max_connection_interval: int
    min_connection_interval: int
    balanced: BluetoothLEPreferredConnectionParameters
    power_optimized: BluetoothLEPreferredConnectionParameters
    throughput_optimized: BluetoothLEPreferredConnectionParameters

class BluetoothLEPreferredConnectionParametersRequest(bleak_winrt.windows.foundation.IClosable, typing.ContextManager[BluetoothLEPreferredConnectionParametersRequest], _winrt.winrt_base):
    ...
    status: BluetoothLEPreferredConnectionParametersRequestStatus
    def close() -> None:
        ...

class BluetoothSignalStrengthFilter(_winrt.winrt_base):
    ...
    sampling_interval: bleak_winrt.windows.foundation.IReference[bleak_winrt.windows.foundation.TimeSpan]
    out_of_range_timeout: bleak_winrt.windows.foundation.IReference[bleak_winrt.windows.foundation.TimeSpan]
    out_of_range_threshold_in_d_bm: bleak_winrt.windows.foundation.IReference[int]
    in_range_threshold_in_d_bm: bleak_winrt.windows.foundation.IReference[int]

class BluetoothUuidHelper(_winrt.winrt_base):
    ...
    def from_short_id(short_id: int) -> uuid.UUID:
        ...
    def try_get_short_id(uuid: uuid.UUID) -> bleak_winrt.windows.foundation.IReference[int]:
        ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum

import bleak_winrt

_ns_module = bleak_winrt._import_ns_module("Windows.Foundation")

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

class AsyncStatus(enum.IntEnum):
    CANCELED = 2
    COMPLETED = 1
    ERROR = 3
    STARTED = 0

class PropertyType(enum.IntEnum):
    EMPTY = 0
    UINT8 = 1
    INT16 = 2
    UINT16 = 3
    INT32 = 4
    UINT32 = 5
    INT64 = 6
    UINT64 = 7
    SINGLE = 8
    DOUBLE = 9
    CHAR16 = 10
    BOOLEAN = 11
    STRING = 12
    INSPECTABLE = 13
    DATE_TIME = 14
    TIME_SPAN = 15
    GUID = 16
    POINT = 17
    SIZE = 18
    RECT = 19
    OTHER_TYPE = 20
    UINT8_ARRAY = 1025
    INT16_ARRAY = 1026
    UINT16_ARRAY = 1027
    INT32_ARRAY = 1028
    UINT32_ARRAY = 1029
    INT64_ARRAY = 1030
    UINT64_ARRAY = 1031
    SINGLE_ARRAY = 1032
    DOUBLE_ARRAY = 1033
    CHAR16_ARRAY = 1034
    BOOLEAN_ARRAY = 1035
    STRING_ARRAY = 1036
    INSPECTABLE_ARRAY = 1037
    DATE_TIME_ARRAY = 1038
    TIME_SPAN_ARRAY = 1039
    GUID_ARRAY = 1040
    POINT_ARRAY = 1041
    SIZE_ARRAY = 1042
    RECT_ARRAY = 1043
    OTHER_TYPE_ARRAY = 1044

DateTime = _ns_module.DateTime
EventRegistrationToken = _ns_module.EventRegistrationToken
HResult = _ns_module.HResult
Point = _ns_module.Point
Rect = _ns_module.Rect
Size = _ns_module.Size
TimeSpan = _ns_module.TimeSpan
Deferral = _ns_module.Deferral
GuidHelper = _ns_module.GuidHelper
MemoryBuffer = _ns_module.MemoryBuffer
PropertyValue = _ns_module.PropertyValue
Uri = _ns_module.Uri
WwwFormUrlDecoder = _ns_module.WwwFormUrlDecoder
WwwFormUrlDecoderEntry = _ns_module.WwwFormUrlDecoderEntry
IAsyncAction = _ns_module.IAsyncAction
IAsyncActionWithProgress = _ns_module.IAsyncActionWithProgress
IAsyncInfo = _ns_module.IAsyncInfo
IAsyncOperationWithProgress = _ns_module.IAsyncOperationWithProgress
IAsyncOperation = _ns_module.IAsyncOperation
IClosable = _ns_module.IClosable
IGetActivationFactory = _ns_module.IGetActivationFactory
IMemoryBuffer = _ns_module.IMemoryBuffer
IMemoryBufferReference = _ns_module.IMemoryBufferReference
IPropertyValue = _ns_module.IPropertyValue
IReferenceArray = _ns_module.IReferenceArray
IReference = _ns_module.IReference
IStringable = _ns_module.IStringable
IWwwFormUrlDecoderEntry = _ns_module.IWwwFormUrlDecoderEntry



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import setuptools

setuptools.setup(
    name = "bleak_winrt",
    version = "1.0a0",
    description="Generated Python/WinRT package",
    license="MIT",
    url="http://github.com/Microsoft/xlang",
    package_data={ "bleak_winrt":["_winrt.pyd", "py.typed"] },
    packages = setuptools.find_namespace_packages(where='.', include=("bleak_winrt*")))



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum

import bleak_winrt

_ns_module = bleak_winrt._import_ns_module("Windows.Devices.Enumeration")

try:
    import bleak_winrt.windows.applicationmodel.background
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.security.credentials
except Exception:
    pass

try:
    import bleak_winrt.windows.storage.streams
except Exception:
    pass

try:
    import bleak_winrt.windows.ui
except Exception:
    pass

try:
    import bleak_winrt.windows.ui.popups
except Exception:
    pass

class DeviceAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

class DeviceClass(enum.IntEnum):
    ALL = 0
    AUDIO_CAPTURE = 1
    AUDIO_RENDER = 2
    PORTABLE_STORAGE_DEVICE = 3
    VIDEO_CAPTURE = 4
    IMAGE_SCANNER = 5
    LOCATION = 6

class DeviceInformationKind(enum.IntEnum):
    UNKNOWN = 0
    DEVICE_INTERFACE = 1
    DEVICE_CONTAINER = 2
    DEVICE = 3
    DEVICE_INTERFACE_CLASS = 4
    ASSOCIATION_ENDPOINT = 5
    ASSOCIATION_ENDPOINT_CONTAINER = 6
    ASSOCIATION_ENDPOINT_SERVICE = 7
    DEVICE_PANEL = 8

class DevicePairingKinds(enum.IntFlag):
    NONE = 0
    CONFIRM_ONLY = 0x1
    DISPLAY_PIN = 0x2
    PROVIDE_PIN = 0x4
    CONFIRM_PIN_MATCH = 0x8
    PROVIDE_PASSWORD_CREDENTIAL = 0x10

class DevicePairingProtectionLevel(enum.IntEnum):
    DEFAULT = 0
    NONE = 1
    ENCRYPTION = 2
    ENCRYPTION_AND_AUTHENTICATION = 3

class DevicePairingResultStatus(enum.IntEnum):
    PAIRED = 0
    NOT_READY_TO_PAIR = 1
    NOT_PAIRED = 2
    ALREADY_PAIRED = 3
    CONNECTION_REJECTED = 4
    TOO_MANY_CONNECTIONS = 5
    HARDWARE_FAILURE = 6
    AUTHENTICATION_TIMEOUT = 7
    AUTHENTICATION_NOT_ALLOWED = 8
    AUTHENTICATION_FAILURE = 9
    NO_SUPPORTED_PROFILES = 10
    PROTECTION_LEVEL_COULD_NOT_BE_MET = 11
    ACCESS_DENIED = 12
    INVALID_CEREMONY_DATA = 13
    PAIRING_CANCELED = 14
    OPERATION_ALREADY_IN_PROGRESS = 15
    REQUIRED_HANDLER_NOT_REGISTERED = 16
    REJECTED_BY_HANDLER = 17
    REMOTE_DEVICE_HAS_ASSOCIATION = 18
    FAILED = 19

class DevicePickerDisplayStatusOptions(enum.IntFlag):
    NONE = 0
    SHOW_PROGRESS = 0x1
    SHOW_DISCONNECT_BUTTON = 0x2
    SHOW_RETRY_BUTTON = 0x4

class DeviceUnpairingResultStatus(enum.IntEnum):
    UNPAIRED = 0
    ALREADY_UNPAIRED = 1
    OPERATION_ALREADY_IN_PROGRESS = 2
    ACCESS_DENIED = 3
    FAILED = 4

class DeviceWatcherEventKind(enum.IntEnum):
    ADD = 0
    UPDATE = 1
    REMOVE = 2

class DeviceWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class Panel(enum.IntEnum):
    UNKNOWN = 0
    FRONT = 1
    BACK = 2
    TOP = 3
    BOTTOM = 4
    LEFT = 5
    RIGHT = 6

DeviceAccessChangedEventArgs = _ns_module.DeviceAccessChangedEventArgs
DeviceAccessInformation = _ns_module.DeviceAccessInformation
DeviceConnectionChangeTriggerDetails = _ns_module.DeviceConnectionChangeTriggerDetails
DeviceDisconnectButtonClickedEventArgs = _ns_module.DeviceDisconnectButtonClickedEventArgs
DeviceInformation = _ns_module.DeviceInformation
DeviceInformationCollection = _ns_module.DeviceInformationCollection
DeviceInformationCustomPairing = _ns_module.DeviceInformationCustomPairing
DeviceInformationPairing = _ns_module.DeviceInformationPairing
DeviceInformationUpdate = _ns_module.DeviceInformationUpdate
DevicePairingRequestedEventArgs = _ns_module.DevicePairingRequestedEventArgs
DevicePairingResult = _ns_module.DevicePairingResult
DevicePicker = _ns_module.DevicePicker
DevicePickerAppearance = _ns_module.DevicePickerAppearance
DevicePickerFilter = _ns_module.DevicePickerFilter
DeviceSelectedEventArgs = _ns_module.DeviceSelectedEventArgs
DeviceThumbnail = _ns_module.DeviceThumbnail
DeviceUnpairingResult = _ns_module.DeviceUnpairingResult
DeviceWatcher = _ns_module.DeviceWatcher
DeviceWatcherEvent = _ns_module.DeviceWatcherEvent
DeviceWatcherTriggerDetails = _ns_module.DeviceWatcherTriggerDetails
EnclosureLocation = _ns_module.EnclosureLocation
IDevicePairingSettings = _ns_module.IDevicePairingSettings



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum
import typing
import uuid

import bleak_winrt._winrt as _winrt
try:
    import bleak_winrt.windows.devices.bluetooth
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.storage.streams
except Exception:
    pass

class BluetoothLEAdvertisementFlags(enum.IntFlag):
    NONE = 0
    LIMITED_DISCOVERABLE_MODE = 0x1
    GENERAL_DISCOVERABLE_MODE = 0x2
    CLASSIC_NOT_SUPPORTED = 0x4
    DUAL_MODE_CONTROLLER_CAPABLE = 0x8
    DUAL_MODE_HOST_CAPABLE = 0x10

class BluetoothLEAdvertisementPublisherStatus(enum.IntEnum):
    CREATED = 0
    WAITING = 1
    STARTED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class BluetoothLEAdvertisementType(enum.IntEnum):
    CONNECTABLE_UNDIRECTED = 0
    CONNECTABLE_DIRECTED = 1
    SCANNABLE_UNDIRECTED = 2
    NON_CONNECTABLE_UNDIRECTED = 3
    SCAN_RESPONSE = 4
    EXTENDED = 5

class BluetoothLEAdvertisementWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    STOPPING = 2
    STOPPED = 3
    ABORTED = 4

class BluetoothLEScanningMode(enum.IntEnum):
    PASSIVE = 0
    ACTIVE = 1
    NONE = 2

class BluetoothLEAdvertisement(_winrt.winrt_base):
    ...
    local_name: str
    flags: bleak_winrt.windows.foundation.IReference[BluetoothLEAdvertisementFlags]
    data_sections: bleak_winrt.windows.foundation.collections.IVector[BluetoothLEAdvertisementDataSection]
    manufacturer_data: bleak_winrt.windows.foundation.collections.IVector[BluetoothLEManufacturerData]
    service_uuids: bleak_winrt.windows.foundation.collections.IVector[uuid.UUID]
    def get_manufacturer_data_by_company_id(company_id: int) -> bleak_winrt.windows.foundation.collections.IVectorView[BluetoothLEManufacturerData]:
        ...
    def get_sections_by_type(type: int) -> bleak_winrt.windows.foundation.collections.IVectorView[BluetoothLEAdvertisementDataSection]:
        ...

class BluetoothLEAdvertisementBytePattern(_winrt.winrt_base):
    ...
    offset: int
    data_type: int
    data: bleak_winrt.windows.storage.streams.IBuffer

class BluetoothLEAdvertisementDataSection(_winrt.winrt_base):
    ...
    data_type: int
    data: bleak_winrt.windows.storage.streams.IBuffer

class BluetoothLEAdvertisementDataTypes(_winrt.winrt_base):
    ...
    advertising_interval: int
    appearance: int
    complete_local_name: int
    complete_service128_bit_uuids: int
    complete_service16_bit_uuids: int
    complete_service32_bit_uuids: int
    flags: int
    incomplete_service128_bit_uuids: int
    incomplete_service16_bit_uuids: int
    incomplete_service32_bit_uuids: int
    manufacturer_specific_data: int
    public_target_address: int
    random_target_address: int
    service_data128_bit_uuids: int
    service_data16_bit_uuids: int
    service_data32_bit_uuids: int
    service_solicitation128_bit_uuids: int
    service_solicitation16_bit_uuids: int
    service_solicitation32_bit_uuids: int
    shortened_local_name: int
    slave_connection_interval_range: int
    tx_power_level: int

class BluetoothLEAdvertisementFilter(_winrt.winrt_base):
    ...
    advertisement: BluetoothLEAdvertisement
    byte_patterns: bleak_winrt.windows.foundation.collections.IVector[BluetoothLEAdvertisementBytePattern]

class BluetoothLEAdvertisementPublisher(_winrt.winrt_base):
    ...
    advertisement: BluetoothLEAdvertisement
    status: BluetoothLEAdvertisementPublisherStatus
    use_extended_advertisement: bool
    preferred_transmit_power_level_in_d_bm: bleak_winrt.windows.foundation.IReference[int]
    is_anonymous: bool
    include_transmit_power_level: bool
    def start() -> None:
        ...
    def stop() -> None:
        ...
    def add_status_changed(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothLEAdvertisementPublisher, BluetoothLEAdvertisementPublisherStatusChangedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_status_changed(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class BluetoothLEAdvertisementPublisherStatusChangedEventArgs(_winrt.winrt_base):
    ...
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    status: BluetoothLEAdvertisementPublisherStatus
    selected_transmit_power_level_in_d_bm: bleak_winrt.windows.foundation.IReference[int]

class BluetoothLEAdvertisementReceivedEventArgs(_winrt.winrt_base):
    ...
    advertisement: BluetoothLEAdvertisement
    advertisement_type: BluetoothLEAdvertisementType
    bluetooth_address: int
    raw_signal_strength_in_d_bm: int
    timestamp: bleak_winrt.windows.foundation.DateTime
    bluetooth_address_type: bleak_winrt.windows.devices.bluetooth.BluetoothAddressType
    is_anonymous: bool
    is_connectable: bool
    is_directed: bool
    is_scan_response: bool
    is_scannable: bool
    transmit_power_level_in_d_bm: bleak_winrt.windows.foundation.IReference[int]

class BluetoothLEAdvertisementWatcher(_winrt.winrt_base):
    ...
    signal_strength_filter: bleak_winrt.windows.devices.bluetooth.BluetoothSignalStrengthFilter
    scanning_mode: BluetoothLEScanningMode
    advertisement_filter: BluetoothLEAdvertisementFilter
    max_out_of_range_timeout: bleak_winrt.windows.foundation.TimeSpan
    max_sampling_interval: bleak_winrt.windows.foundation.TimeSpan
    min_out_of_range_timeout: bleak_winrt.windows.foundation.TimeSpan
    min_sampling_interval: bleak_winrt.windows.foundation.TimeSpan
    status: BluetoothLEAdvertisementWatcherStatus
    allow_extended_advertisements: bool
    def start() -> None:
        ...
    def stop() -> None:
        ...
    def add_received(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothLEAdvertisementWatcher, BluetoothLEAdvertisementReceivedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_received(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...
    def add_stopped(handler: bleak_winrt.windows.foundation.TypedEventHandler[BluetoothLEAdvertisementWatcher, BluetoothLEAdvertisementWatcherStoppedEventArgs]) -> bleak_winrt.windows.foundation.EventRegistrationToken:
        ...
    def remove_stopped(token: bleak_winrt.windows.foundation.EventRegistrationToken) -> None:
        ...

class BluetoothLEAdvertisementWatcherStoppedEventArgs(_winrt.winrt_base):
    ...
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError

class BluetoothLEManufacturerData(_winrt.winrt_base):
    ...
    data: bleak_winrt.windows.storage.streams.IBuffer
    company_id: int




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum

import bleak_winrt

_ns_module = bleak_winrt._import_ns_module("Windows.Devices.Bluetooth")

try:
    import bleak_winrt.windows.devices.bluetooth.genericattributeprofile
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.rfcomm
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.enumeration
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.radios
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.networking
except Exception:
    pass

try:
    import bleak_winrt.windows.storage.streams
except Exception:
    pass

class BluetoothAddressType(enum.IntEnum):
    PUBLIC = 0
    RANDOM = 1
    UNSPECIFIED = 2

class BluetoothCacheMode(enum.IntEnum):
    CACHED = 0
    UNCACHED = 1

class BluetoothConnectionStatus(enum.IntEnum):
    DISCONNECTED = 0
    CONNECTED = 1

class BluetoothError(enum.IntEnum):
    SUCCESS = 0
    RADIO_NOT_AVAILABLE = 1
    RESOURCE_IN_USE = 2
    DEVICE_NOT_CONNECTED = 3
    OTHER_ERROR = 4
    DISABLED_BY_POLICY = 5
    NOT_SUPPORTED = 6
    DISABLED_BY_USER = 7
    CONSENT_REQUIRED = 8
    TRANSPORT_NOT_SUPPORTED = 9

class BluetoothLEPreferredConnectionParametersRequestStatus(enum.IntEnum):
    UNSPECIFIED = 0
    SUCCESS = 1
    DEVICE_NOT_AVAILABLE = 2
    ACCESS_DENIED = 3

class BluetoothMajorClass(enum.IntEnum):
    MISCELLANEOUS = 0
    COMPUTER = 1
    PHONE = 2
    NETWORK_ACCESS_POINT = 3
    AUDIO_VIDEO = 4
    PERIPHERAL = 5
    IMAGING = 6
    WEARABLE = 7
    TOY = 8
    HEALTH = 9

class BluetoothMinorClass(enum.IntEnum):
    UNCATEGORIZED = 0
    COMPUTER_DESKTOP = 1
    COMPUTER_SERVER = 2
    COMPUTER_LAPTOP = 3
    COMPUTER_HANDHELD = 4
    COMPUTER_PALM_SIZE = 5
    COMPUTER_WEARABLE = 6
    COMPUTER_TABLET = 7
    PHONE_CELLULAR = 1
    PHONE_CORDLESS = 2
    PHONE_SMART_PHONE = 3
    PHONE_WIRED = 4
    PHONE_ISDN = 5
    NETWORK_FULLY_AVAILABLE = 0
    NETWORK_USED01_TO17_PERCENT = 8
    NETWORK_USED17_TO33_PERCENT = 16
    NETWORK_USED33_TO50_PERCENT = 24
    NETWORK_USED50_TO67_PERCENT = 32
    NETWORK_USED67_TO83_PERCENT = 40
    NETWORK_USED83_TO99_PERCENT = 48
    NETWORK_NO_SERVICE_AVAILABLE = 56
    AUDIO_VIDEO_WEARABLE_HEADSET = 1
    AUDIO_VIDEO_HANDS_FREE = 2
    AUDIO_VIDEO_MICROPHONE = 4
    AUDIO_VIDEO_LOUDSPEAKER = 5
    AUDIO_VIDEO_HEADPHONES = 6
    AUDIO_VIDEO_PORTABLE_AUDIO = 7
    AUDIO_VIDEO_CAR_AUDIO = 8
    AUDIO_VIDEO_SET_TOP_BOX = 9
    AUDIO_VIDEO_HIFI_AUDIO_DEVICE = 10
    AUDIO_VIDEO_VCR = 11
    AUDIO_VIDEO_VIDEO_CAMERA = 12
    AUDIO_VIDEO_CAMCORDER = 13
    AUDIO_VIDEO_VIDEO_MONITOR = 14
    AUDIO_VIDEO_VIDEO_DISPLAY_AND_LOUDSPEAKER = 15
    AUDIO_VIDEO_VIDEO_CONFERENCING = 16
    AUDIO_VIDEO_GAMING_OR_TOY = 18
    PERIPHERAL_JOYSTICK = 1
    PERIPHERAL_GAMEPAD = 2
    PERIPHERAL_REMOTE_CONTROL = 3
    PERIPHERAL_SENSING = 4
    PERIPHERAL_DIGITIZER_TABLET = 5
    PERIPHERAL_CARD_READER = 6
    PERIPHERAL_DIGITAL_PEN = 7
    PERIPHERAL_HANDHELD_SCANNER = 8
    PERIPHERAL_HANDHELD_GESTURE = 9
    WEARABLE_WRISTWATCH = 1
    WEARABLE_PAGER = 2
    WEARABLE_JACKET = 3
    WEARABLE_HELMET = 4
    WEARABLE_GLASSES = 5
    TOY_ROBOT = 1
    TOY_VEHICLE = 2
    TOY_DOLL = 3
    TOY_CONTROLLER = 4
    TOY_GAME = 5
    HEALTH_BLOOD_PRESSURE_MONITOR = 1
    HEALTH_THERMOMETER = 2
    HEALTH_WEIGHING_SCALE = 3
    HEALTH_GLUCOSE_METER = 4
    HEALTH_PULSE_OXIMETER = 5
    HEALTH_HEART_RATE_MONITOR = 6
    HEALTH_HEALTH_DATA_DISPLAY = 7
    HEALTH_STEP_COUNTER = 8
    HEALTH_BODY_COMPOSITION_ANALYZER = 9
    HEALTH_PEAK_FLOW_MONITOR = 10
    HEALTH_MEDICATION_MONITOR = 11
    HEALTH_KNEE_PROSTHESIS = 12
    HEALTH_ANKLE_PROSTHESIS = 13
    HEALTH_GENERIC_HEALTH_MANAGER = 14
    HEALTH_PERSONAL_MOBILITY_DEVICE = 15

class BluetoothServiceCapabilities(enum.IntFlag):
    NONE = 0
    LIMITED_DISCOVERABLE_MODE = 0x1
    POSITIONING_SERVICE = 0x8
    NETWORKING_SERVICE = 0x10
    RENDERING_SERVICE = 0x20
    CAPTURING_SERVICE = 0x40
    OBJECT_TRANSFER_SERVICE = 0x80
    AUDIO_SERVICE = 0x100
    TELEPHONE_SERVICE = 0x200
    INFORMATION_SERVICE = 0x400

BluetoothAdapter = _ns_module.BluetoothAdapter
BluetoothClassOfDevice = _ns_module.BluetoothClassOfDevice
BluetoothDevice = _ns_module.BluetoothDevice
BluetoothDeviceId = _ns_module.BluetoothDeviceId
BluetoothLEAppearance = _ns_module.BluetoothLEAppearance
BluetoothLEAppearanceCategories = _ns_module.BluetoothLEAppearanceCategories
BluetoothLEAppearanceSubcategories = _ns_module.BluetoothLEAppearanceSubcategories
BluetoothLEConnectionParameters = _ns_module.BluetoothLEConnectionParameters
BluetoothLEConnectionPhy = _ns_module.BluetoothLEConnectionPhy
BluetoothLEConnectionPhyInfo = _ns_module.BluetoothLEConnectionPhyInfo
BluetoothLEDevice = _ns_module.BluetoothLEDevice
BluetoothLEPreferredConnectionParameters = _ns_module.BluetoothLEPreferredConnectionParameters
BluetoothLEPreferredConnectionParametersRequest = _ns_module.BluetoothLEPreferredConnectionParametersRequest
BluetoothSignalStrengthFilter = _ns_module.BluetoothSignalStrengthFilter
BluetoothUuidHelper = _ns_module.BluetoothUuidHelper



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

from . import _winrt

def _import_ns_module(ns):
    import importlib.machinery
    import importlib.util

    try:
        module_name = "_bleak_winrt_" + ns.replace('.', '_')

        loader = importlib.machinery.ExtensionFileLoader(module_name, _winrt.__file__)
        spec = importlib.util.spec_from_loader(module_name, loader)
        module = importlib.util.module_from_spec(spec)
        loader.exec_module(module)
        return module
    except Exception:
        return None
